<?php
/*
Plugin Name: NovinPal Paid Download - دانلود به ازای پرداخت نوین پال
Plugin URI: https://wordpress.org/plugins/novinpal-paid-download
Description: این افزونه امکان فروش فایل را از طریق درگاه پرداخت نوین پال برای شما فراهم می نماید.
Version: 1.0.0
Author: NovinPal
Author URI: https://www.novinpal.ir/
*/

const NOVINPAL_PD_RECORDS_PER_PAGE = '20';
const NOVINPAL_PD_VERSION = 2.0;

wp_enqueue_script('jquery');
register_activation_hook(__FILE__, ["NovinPalPaidDownload", "install"]);

class NovinPalPaidDownload
{
    const BASE_URL = 'https://api.novinpal.ir/';
    private $getTokenUrl = NovinPalPaidDownload::BASE_URL . 'invoice/request';
    private $toTerminalUrl = NovinPalPaidDownload::BASE_URL . 'invoice/start/{refId}';
    private $verifyUrl = NovinPalPaidDownload::BASE_URL . 'invoice/verify';

    private $options;
    private $error;
    private $info;
    private $currency_list;

    private $novinpal_currency_list = ["ریال", "تومان"];
    private $buynow_buttons_list = ["html", "novinpal", "css3", "custom"];

    function __construct()
    {

        if (function_exists('load_plugin_textdomain')) {

            load_plugin_textdomain('novinpalpaiddownload', false, dirname(plugin_basename(__FILE__)) . '/languages/');
        }

        $this->currency_list = array_unique(array_merge($this->novinpal_currency_list));
        sort($this->currency_list);
        $this->currency_list = array_unique(array_merge(["تومان"], $this->currency_list));

        $this->options = array(
            "exists"                => 1,
            "version"               => NOVINPAL_PD_VERSION,
            "enable_novinpal"       => "on",
            "apikey"                => "",
            "currency"              => $this->novinpal_currency_list[1],
            "seller_email"          => "alerts@" . str_replace("www.", "", $_SERVER["SERVER_NAME"]),
            "from_name"             => get_bloginfo("name"),
            "from_email"            => "noreply@" . str_replace("www.", "", $_SERVER["SERVER_NAME"]),
            "success_email_subject" => __('جزئیات دانلود محصول', 'novinpalpaiddownload'),
            "success_email_body"    => __('کاربر گرامی {name}،', 'novinpalpaiddownload') . PHP_EOL . PHP_EOL . __('ضمن تشکر از شما بابت خرید محصول {product_title}، جهت دانلود  برروی لینک زیر کلیک نمایید :', 'novinpalpaiddownload') . PHP_EOL . '{download_link}' . PHP_EOL . __('توجه داشته باشید لینک فوق تنها به مدت {download_link_lifetime} روز دارای اعتبار جهت دریافت می باشد.', 'novinpalpaiddownload') . PHP_EOL . PHP_EOL . __('با تشکر', 'novinpalpaiddownload'),
            "failed_email_subject"  => __('عملیات ناموفق پرداخت', 'novinpalpaiddownload'),
            "failed_email_body"     => __('کاربر گرامی {name}،', 'novinpalpaiddownload') . PHP_EOL . PHP_EOL . __('ضمن تشکر از شما جهت انتخاب محصول {product_title} ،', 'novinpalpaiddownload') . PHP_EOL . __('پرداخت شما با وضعیت " {payment_status} " در سیستم ثبت شده است.', 'novinpalpaiddownload') . PHP_EOL . __('در صورتی که پس از بررسی پرداخت شما موفقیت آمیز بوده باشد جزئیات محصول اصلاح خواهد شد.', 'novinpalpaiddownload') . PHP_EOL . PHP_EOL . __('با تشکر', 'novinpalpaiddownload'),
            "buynow_type"           => "html",
            "buy_now_image"         => "",
            "link_lifetime"         => "2",
            "terms"                 => "",
            "getphonenumber"        => "off",
            "showdownloadlink"      => "off"
        );

        if (!empty($_COOKIE["novinpalpaiddownload_error"])) {

            $this->error = stripslashes($_COOKIE["novinpalpaiddownload_error"]);
            setcookie("novinpalpaiddownload_error", "", (time() + 30), "/", "." . str_replace("www.", "", $_SERVER["SERVER_NAME"]));
        }

        if (!empty($_COOKIE["novinpalpaiddownload_info"])) {

            $this->info = stripslashes($_COOKIE["novinpalpaiddownload_info"]);
            setcookie("novinpalpaiddownload_info", "", (time() + 30), "/", "." . str_replace("www.", "", $_SERVER["SERVER_NAME"]));
        }

        $this->novinpal_get_settings();

        if (is_admin()) {

            if ($this->novinpal_check_settings() !== true) {

                add_action('admin_notices', [&$this, 'novinpal_admin_warning']);
            }

            if (!file_exists(ABSPATH . 'wp-content/uploads/paid-download/files')) {

                add_action('admin_notices', [&$this, 'novinpal_admin_warning_reactivate']);
            }

            add_action('admin_menu', [&$this, 'novinpal_admin_menu']);
            add_action('init', [&$this, 'novinpal_admin_request_handler']);
            add_action('admin_head', [&$this, 'novinpal_admin_header'], 15);

            return;
        }

        add_action("init", [&$this, "novinpal_front_init"]);
        add_action("wp_head", [&$this, "novinpal_front_header"]);
        add_shortcode('paid-download', [&$this, "novinpal_shortcode_handler"]);
        add_shortcode('novinpalpaiddownload', [&$this, "novinpal_shortcode_handler"]);
    }

    static function install()
    {
        global $wpdb;

        $table_name = $wpdb->prefix . "pd_orders";
        $sql = "CREATE TABLE IF NOT EXISTS " . $table_name . " (
				id int(11) NOT NULL auto_increment,
                file_id int(11) NOT NULL,
				payer_name varchar(255) collate utf8_unicode_ci NOT NULL,
				payer_phone varchar(255) collate utf8_unicode_ci NOT NULL,
				payer_email varchar(255) collate utf8_unicode_ci NOT NULL,
				completed int(11) NOT NULL default '0',
				UNIQUE KEY  id (id)
			);";

        require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
        dbDelta($sql);

        $table_name = $wpdb->prefix . "pd_files";
        $sql = "CREATE TABLE IF NOT EXISTS " . $table_name . " (
				id int(11) NOT NULL auto_increment,
				title varchar(255) collate utf8_unicode_ci NOT NULL,
				filename varchar(255) collate utf8_unicode_ci NOT NULL,
				uploaded int(11) NOT NULL default '1',
				filename_original varchar(255) collate utf8_unicode_ci NOT NULL,
				price float NOT NULL,
				currency varchar(7) collate utf8_unicode_ci NOT NULL,
				available_copies int(11) NOT NULL default '0',
				license_url varchar(255) NOT NULL default '',
				registered int(11) NOT NULL,
				deleted int(11) NOT NULL default '0',
				UNIQUE KEY  id (id)
			);";

        require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
        dbDelta($sql);

        $table_name = $wpdb->prefix . "pd_downloadlinks";
        $sql = "CREATE TABLE IF NOT EXISTS " . $table_name . " (
				id int(11) NOT NULL auto_increment,
				file_id int(11) NOT NULL,
				download_key varchar(255) collate utf8_unicode_ci NOT NULL,
				owner varchar(63) collate utf8_unicode_ci NOT NULL,
				source varchar(15) collate utf8_unicode_ci NOT NULL,
				created int(11) NOT NULL,
				deleted int(11) NOT NULL default '0',
				UNIQUE KEY  id (id)
			);";

        require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
        dbDelta($sql);

        $table_name = $wpdb->prefix . "pd_transactions";
        $sql = "CREATE TABLE IF NOT EXISTS " . $table_name . " (
				id int(11) NOT NULL auto_increment,
				file_id int(11) NOT NULL,
				payer_name varchar(255) collate utf8_unicode_ci NOT NULL,
                payer_phone varchar(255) collate utf8_unicode_ci NOT NULL,
				payer_email varchar(255) collate utf8_unicode_ci NOT NULL,
				gross float NOT NULL,
				currency varchar(15) collate utf8_unicode_ci NOT NULL,
				payment_status varchar(31) collate utf8_unicode_ci NOT NULL,
				transaction_type varchar(31) collate utf8_unicode_ci NOT NULL,
				details text collate utf8_unicode_ci NOT NULL,
				created int(11) NOT NULL,
				deleted int(11) NOT NULL default '0',
				UNIQUE KEY  id (id)
			);";

        require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
        dbDelta($sql);

        if (!file_exists(ABSPATH . 'wp-content/uploads/paid-download')) {

            wp_mkdir_p(ABSPATH . 'wp-content/uploads/paid-download');

            if (!file_exists(ABSPATH . 'wp-content/uploads/paid-download/index.html')) {

                file_put_contents(ABSPATH . 'wp-content/uploads/paid-download/index.html', 'Silence is the gold!');
            }

            if (!file_exists(ABSPATH . 'wp-content/uploads/paid-download/files')) {

                wp_mkdir_p(ABSPATH . 'wp-content/uploads/paid-download/files');

                if (!file_exists(ABSPATH . 'wp-content/uploads/paid-download/files/.htaccess')) {

                    file_put_contents(ABSPATH . 'wp-content/uploads/paid-download/files/.htaccess', 'deny from all');
                }
            }
        }
    }

    function novinpal_get_settings()
    {
        $exists = get_option('novinpalpaiddownload_version');

        if (!$exists) {

            return;
        }

        foreach ($this->options as $key => $value) {

            $this->options[$key] = get_option('novinpalpaiddownload_' . $key);
        }
    }

    function novinpal_update_settings()
    {
        foreach ($this->options as $key => $value) {

            update_option('novinpalpaiddownload_' . $key, $value);
        }
    }

    function novinpal_populate_settings()
    {
        foreach ($this->options as $key => $value) {

            if (isset($_POST['novinpalpaiddownload_' . $key])) {

                $this->options[$key] = stripslashes($_POST['novinpalpaiddownload_' . $key]);
            }
        }
    }

    function novinpal_check_settings()
    {
        $errors = [];
        if (strlen($this->options['apikey']) < 3) {

            $errors[] = __('وارد کردن کلید API نوین پال الزامی است', 'novinpalpaiddownload');
        }

        if (!preg_match("/^[_a-z0-9-]+(\.[_a-z0-9-]+)*@[a-z0-9-]+(\.[a-z0-9-]+)*(\.[a-z]{2,4})$/i", $this->options['seller_email']) || strlen($this->options['seller_email']) == 0) {

            $errors[] = __('ایمیل وارد شده جهت دریافت اطلاع رسانی ها صحیح نیست', 'novinpalpaiddownload');
        }

        if (!preg_match("/^[_a-z0-9-]+(\.[_a-z0-9-]+)*@[a-z0-9-]+(\.[a-z0-9-]+)*(\.[a-z]{2,4})$/i", $this->options['from_email']) || strlen($this->options['from_email']) == 0) {

            $errors[] = __('آدرس ایمیل وارد شده برای فروشگاه صحیح نیست', 'novinpalpaiddownload');
        }

        if (strlen($this->options['from_name']) < 3) {

            $errors[] = __('نام فروشگاه کمتر از 3 کاراکتر است', 'novinpalpaiddownload');
        }

        if (strlen($this->options['success_email_subject']) < 3) {

            $errors[] = __('عنوان ایمیل خرید موفقیت آمیز باید حداقل دارای 3 کاراکتر باشد', 'novinpalpaiddownload');
        } else if (strlen($this->options['success_email_subject']) > 64) {

            $errors[] = __('عنوان ایمیل خرید موفقیت آمیز باید حداکثر دارای 64 کاراکتر باشد', 'novinpalpaiddownload');
        }

        if (strlen($this->options['success_email_body']) < 3) {

            $errors[] = __('متن ایمیل خرید موفقیت آمیز باید حداقل دارای 3 کاراکتر باشد', 'novinpalpaiddownload');
        }

        if (strlen($this->options['failed_email_subject']) < 3) {

            $errors[] = __('عنوان ایمیل خرید ناموفق باید حداقل دارای 3 کاراکتر باشد', 'novinpalpaiddownload');
        } else if (strlen($this->options['failed_email_subject']) > 64) {

            $errors[] = __('عنوان ایمیل خرید ناموفق باید حداکثر دارای 64 کاراکتر باشد', 'novinpalpaiddownload');
        }

        if (strlen($this->options['failed_email_body']) < 3) {

            $errors[] = __('متن ایمیل خرید ناموفق باید حداقل دارای 3 کاراکتر باشد', 'novinpalpaiddownload');
        }

        if (intval($this->options['link_lifetime']) != $this->options['link_lifetime'] || intval($this->options['link_lifetime']) < 1 || intval($this->options['link_lifetime']) > 365) {

            $errors[] = __('مدت اعتبار لینک باید بین 1 تا 365 روز باشد', 'novinpalpaiddownload');
        }

        if (empty($errors)) {

            return true;
        }

        return $errors;
    }

    function novinpal_admin_menu()
    {
        get_bloginfo('version') >= 3.0 ? define("NOVINPAL_PAID_DOWNLOAD_PERMISSION", "add_users") : define("NOVINPAL_PAID_DOWNLOAD_PERMISSION", "edit_themes");

        $menuSlug = 'novinpal-paid-download';

        add_menu_page(
            "پرداخت نوین‌پال"
            , "پرداخت نوین‌پال"
            , NOVINPAL_PAID_DOWNLOAD_PERMISSION
            , $menuSlug
            , [&$this, 'novinpal_admin_settings']
        );

        add_submenu_page(
            $menuSlug
            , __('تنظیمات', 'novinpalpaiddownload')
            , __('تنظیمات', 'novinpalpaiddownload')
            , NOVINPAL_PAID_DOWNLOAD_PERMISSION
            , "novinpal-paid-download"
            , [&$this, 'novinpal_admin_settings']
        );

        add_submenu_page(
            $menuSlug
            , __('فایل ها', 'novinpalpaiddownload')
            , __('فایل ها', 'novinpalpaiddownload')
            , NOVINPAL_PAID_DOWNLOAD_PERMISSION
            , "novinpal-paid-download-files"
            , [&$this, 'novinpal_admin_files']
        );

        add_submenu_page(
            $menuSlug
            , __('اضافه کردن فایل', 'novinpalpaiddownload')
            , __('اضافه کردن فایل', 'novinpalpaiddownload')
            , NOVINPAL_PAID_DOWNLOAD_PERMISSION
            , "novinpal-paid-download-add"
            , [&$this, 'novinpal_admin_add_file']
        );

        add_submenu_page(
            $menuSlug
            , __('لینک های دریافت', 'novinpalpaiddownload')
            , __('لینک های دریافت', 'novinpalpaiddownload')
            , NOVINPAL_PAID_DOWNLOAD_PERMISSION
            , "novinpal-paid-download-links"
            , [&$this, 'novinpal_admin_links']
        );

        add_submenu_page(
            $menuSlug
            , __('اضافه کردن لینک', 'novinpalpaiddownload')
            , __('اضافه کردن لینک', 'novinpalpaiddownload')
            , NOVINPAL_PAID_DOWNLOAD_PERMISSION
            , "novinpal-paid-download-add-link"
            , [&$this, 'novinpal_admin_add_link']
        );

        add_submenu_page(
            $menuSlug
            , __('پرداخت ها', 'novinpalpaiddownload')
            , __('پرداخت ها', 'novinpalpaiddownload')
            , NOVINPAL_PAID_DOWNLOAD_PERMISSION
            , "novinpal-paid-download-transactions"
            , [&$this, 'novinpal_admin_transactions']
        );
    }

    function novinpal_admin_settings()
    {
        global $wpdb;

        $message = "";
        $errors = [];

        if (!empty($this->error)) {

            $message = "<div class='error'><p>" . $this->error . "</p></div>";
        } else {

            $errors = $this->novinpal_check_settings();
            if (is_array($errors)) {

                echo "<div class='error'><p>" . __('خطا های موجود در فرم: ', 'novinpalpaiddownload') . "<br />- " . implode("<br />- ", $errors) . "</p></div>";
            }
        }

        if (isset($_GET["updated"]) && $_GET["updated"] == "true") {

            $message = '<div class="updated"><p>' . __('تنظیمات افزونه با <strong>موفقیت</strong> بروزرسانی شد.', 'novinpalpaiddownload') . '</p></div>';
        }

        if (!in_array($this->options['buynow_type'], $this->buynow_buttons_list)) {

            $this->options['buynow_type'] = $this->buynow_buttons_list[0];
        }

        if ($this->options['buynow_type'] == "custom" && empty($this->options['buy_now_image'])) {

            $this->options['buynow_type'] = $this->buynow_buttons_list[0];
        }

        print ('<div class="wrap admin_novinpalpaiddownload_wrap">
			        <div id="icon-options-general" class="icon32"><br /></div><h2>' . __('پرداخت نوین‌پال - تنظیمات', 'novinpalpaiddownload') . '</h2><br/>
			        ' . $message);

        print ('<form enctype="multipart/form-data" method="post" style="margin: 0px" action="' . get_bloginfo('wpurl') . '/wp-admin/admin.php">
    			<div class="postbox-container" style="width: 100%;">
				<div class="metabox-holder">
					<div class="meta-box-sortables ui-sortable">
						<div class="postbox">
							<h3 class="hndle" style="cursor: default;"><span>' . __('تنظیمات اصلی', 'novinpalpaiddownload') . '</span></h3>
							<div class="inside">
								<table class="novinpalpaiddownload_useroptions">
									<tr>
										<th>' . __('ایمیل اطلاع رسانی', 'novinpalpaiddownload') . ':</th>
										<td><input type="text" id="novinpalpaiddownload_seller_email" name="novinpalpaiddownload_seller_email" value="' . htmlspecialchars($this->options['seller_email'], ENT_QUOTES) . '" class="widefat"><br /><em>' . __('لطفا یک آدرس ایمیل جهت دریافت کلیه رویداد ها خرید/پرداخت وارد نمایید.', 'novinpalpaiddownload') . '</em></td>
									</tr>
									<tr>
										<th>' . __('نام فروشگاه', 'novinpalpaiddownload') . ':</th>
										<td><input type="text" id="novinpalpaiddownload_from_name" name="novinpalpaiddownload_from_name" value="' . htmlspecialchars($this->options['from_name'], ENT_QUOTES) . '" class="widefat"><br /><em>' . __('لطفا نام مورد نظر خود جهت پیام های ارسالی به خریدار را در این قسمت تعیین نمایید.', 'novinpalpaiddownload') . '</em></td>
									</tr>
									<tr>
										<th>' . __('ایمیل فروشگاه', 'novinpalpaiddownload') . ':</th>
										<td><input type="text" id="novinpalpaiddownload_from_email" name="novinpalpaiddownload_from_email" value="' . htmlspecialchars($this->options['from_email'], ENT_QUOTES) . '" class="widefat"><br /><em>' . __('تمامی ایمیل های ارسالی برای خریدار از طرف این ایمیل ارسال خواهد شد.', 'novinpalpaiddownload') . '</em></td>
									</tr>
									<tr>
										<th>' . __('عنوان ایمیل خرید موفق', 'novinpalpaiddownload') . ':</th>
										<td><input type="text" id="novinpalpaiddownload_success_email_subject" name="novinpalpaiddownload_success_email_subject" value="' . htmlspecialchars($this->options['success_email_subject'], ENT_QUOTES) . '" class="widefat"><br /><em>' . __('پس از پرداخت موفقیت آمیز پرداخت کننده یک ایمیل با این عنوان دریافت می نماید.', 'novinpalpaiddownload') . '</em></td>
									</tr>
									<tr>
										<th>' . __('متن ایمیل خرید موفق', 'novinpalpaiddownload') . ':</th>
										<td><textarea id="novinpalpaiddownload_success_email_body" name="novinpalpaiddownload_success_email_body" class="widefat" style="height: 120px;">' . htmlspecialchars($this->options['success_email_body'], ENT_QUOTES) . '</textarea><br /><em>' . __('پس از خرید موفقیت آمیز متن فوق برای کاربر ارسال می شود، جهت جایگزینی در هنگام ارسال از فیلد های زیر استفاده نمایید: {name}, {payer_email}, {product_title}, {product_price}, {product_currency}, {download_link}, {download_link_lifetime}, {license_info}.', 'novinpalpaiddownload') . '</em></td>
									</tr>

									<tr>
										<th>' . __('عنوان ایمیل خرید ناموفق', 'novinpalpaiddownload') . ':</th>
										<td><input type="text" id="novinpalpaiddownload_failed_email_subject" name="novinpalpaiddownload_failed_email_subject" value="' . htmlspecialchars($this->options['failed_email_subject'], ENT_QUOTES) . '" class="widefat"><br /><em>' . __('پس از پرداخت ناموفق پرداخت کننده یک ایمیل با این عنوان دریافت می نماید.', 'novinpalpaiddownload') . '</em></td>
									</tr>
									<tr>
										<th>' . __('متن ایمیل خرید ناموفق', 'novinpalpaiddownload') . ':</th>
										<td><textarea id="novinpalpaiddownload_failed_email_body" name="novinpalpaiddownload_failed_email_body" class="widefat" style="height: 120px;">' . htmlspecialchars($this->options['failed_email_body'], ENT_QUOTES) . '</textarea><br /><em>' . __('پس از خرید ناموفق متن فوق برای کاربر ارسال می شود، جهت جایگزینی در هنگام ارسال از فیلد های زیر استفاده نمایید: {name}, {payer_email}, {product_title}, {product_price}, {product_currency}, {payment_status}.', 'novinpalpaiddownload') . '</em></td>
									</tr>
									<tr>
										<th>' . __('مدت اعتبار لینک دانلود', 'novinpalpaiddownload') . ':</th>
										<td><input type="text" id="novinpalpaiddownload_link_lifetime" name="novinpalpaiddownload_link_lifetime" value="' . htmlspecialchars($this->options['link_lifetime'], ENT_QUOTES) . '" style="width: 60px; text-align: right;"> روز<br /><em>' . __('لطفا مدت زمان اعتبار لینک دانلود را تعیین نمایید.', 'novinpalpaiddownload') . '</em></td>
									</tr>
									<tr>
										<th>' . __('نوع کلید خرید', 'novinpalpaiddownload') . ':</th>
										<td>
											<table style="border: 0px; padding: 0px;">
											<tr><td style="padding-top: 8px; width: 20px;"><input type="radio"  name="novinpalpaiddownload_buynow_type" value="html"' . ($this->options['buynow_type'] == "html" ? ' checked="checked"' : '') . '></td><td>' . __('کلید استاندارد HTML', 'novinpalpaiddownload') . '<br /><button style="font-family:tahoma; padding:2px; width:100px" onclick="return false;">' . __('خرید', 'novinpalpaiddownload') . '</button></td></tr>
											<tr><td style="padding-top: 8px;"><input type="radio" name="novinpalpaiddownload_buynow_type" value="novinpal"' . ($this->options['buynow_type'] == "novinpal" ? ' checked="checked"' : '') . '></td><td>' . __('کلید پیش فرض نوین‌پال', 'novinpalpaiddownload') . '<br /><img src="' . plugins_url('/images/btn_buynow_LG.gif', __FILE__) . '" border="0"></td></tr>
											<tr><td style="padding-top: 8px;"><input type="radio" name="novinpalpaiddownload_buynow_type" value="css3"' . ($this->options['buynow_type'] == "css3" ? ' checked="checked"' : '') . '></td><td>' . __('کلید با استفاده از CSS3', 'novinpalpaiddownload') . '<br />
											<a href="#" class="novinpalpaiddownload-btn" onclick="return false;">
  												<span class="novinpalpaiddownload-btn-icon-right"><span></span></span>
												<span class="novinpalpaiddownload-btn-slide-text">1000 تومان</span>
                                                <span class="novinpalpaiddownload-btn-text">' . __('خرید', 'novinpalpaiddownload') . '</span>
											</a>
											</td></tr>
											<tr><td style="padding-top: 8px;"><input type="radio" name="novinpalpaiddownload_buynow_type" value="custom"' . ($this->options['buynow_type'] == "custom" ? ' checked="checked"' : '') . '></td><td>' . __('کلید سفارشی', 'novinpalpaiddownload') . (!empty($this->options['buy_now_image']) ? '<br /><img src="' . get_bloginfo("wpurl") . '/wp-content/uploads/paid-download/' . rawurlencode($this->options['buy_now_image']) . '" border="0">' : '') . '<br /><input type="file" id="novinpalpaiddownload_buy_now_image" name="novinpalpaiddownload_buy_now_image" class="widefat"><br /><em>' . __('مجاز به انتخاب تصویر با ابعاد : 600px در  600px و پسوند : JPG, GIF, PNG.', 'novinpalpaiddownload') . '</em></td></tr>
											</table>
										</td>
									</tr>
                                    <tr>
										<th>' . __('گزینه ها', 'novinpalpaiddownload') . $this->options['getphonenumber'] . ':</th>
										<td>
                                            <input type="checkbox" ' . ($this->options['getphonenumber'] == "on" ? ' checked="checked"' : '') . ' name="novinpalpaiddownload_getphonenumber"  id="novinpalpaiddownload_getphonenumber" /><label for="novinpalpaiddownload_getphonenumber">دریافت شماره تلفن همراه کاربر</label>
                                            <br/>
                                            <input type="checkbox" ' . ($this->options['showdownloadlink'] == "on" ? ' checked="checked"' : '') . ' name="novinpalpaiddownload_showdownloadlink"  id="novinpalpaiddownload_showdownloadlink" /><label for="novinpalpaiddownload_showdownloadlink">نمایش لینک دانلود پایان خرید</label>
                                        </td>
									</tr>
									<tr>
										<th>' . __('قوانین و مقررات', 'novinpalpaiddownload') . ':</th>
										<td><textarea id="novinpalpaiddownload_terms" name="novinpalpaiddownload_terms" class="widefat" style="height: 120px;">' . htmlspecialchars($this->options['terms'], ENT_QUOTES) . '</textarea><br /><em>' . __('در صورتی که نیازمند پذیرش قوانین و مقررات جهت خرید و دانلود فایل های سایت خود هستید از این قسمت استفاده نمایید، خالی گذاشتن فیلد فوق به معنی نداشتن قوانین و مقررات خواهد بود.', 'novinpalpaiddownload') . '</em></td>
									</tr>
								</table>
								<div class="alignright">
								<input type="hidden" name="ak_action" value="novinpalpaiddownload_novinpal_update_settings" />
								<input type="hidden" name="novinpalpaiddownload_exists" value="1" />
								<input type="submit" class="paiddownoads_button button-primary" name="submit" value="' . __('ذخیره تنظیمات', 'novinpalpaiddownload') . ' »">
								</div>
								<br class="clear">
							</div>
						</div>

						<div class="postbox">
							<h3 class="hndle" style="cursor: default;"><span>' . __('تنظیمات درگاه پرداخت نوین‌پال', 'novinpalpaiddownload') . '</span></h3>
							<div class="inside">
								<table class="novinpalpaiddownload_useroptions">
									<tr><th colspan="2">' . (!in_array('curl', get_loaded_extensions()) ? __('جهت استفاده از درگاه نوین‌پال CURL را برروی سرور هاست خود فعال نمایید!', 'novinpalpaiddownload') : __('توجه! جهت دریافت اطلاعات درگاه می بایست از طریق عضویت و دریافت درگاه در سایت <a target="_blank" href="https://www.novinpal.ir">نوین‌پال</a> اقدام نمایید.', 'novinpalpaiddownload')) . '</th></tr>

									<tr>
										<th>' . __('API Key', 'novinpalpaiddownload') . ':</th>
										<td><input type="text" id="novinpalpaiddownload_apikey" name="novinpalpaiddownload_apikey" value="' . htmlspecialchars($this->options['apikey'], ENT_QUOTES) . '" class="widefat"' . (!in_array('curl', get_loaded_extensions()) ? ' disabled="disabled"' : '') . '><br /><em>' . __('لطفا شناسه درگاه دریافتی از نوین‌پال را در این قسمت وارد نمایید.', 'novinpalpaiddownload') . '</em></td>
									</tr>
                                    <tr>
										<th>' . __('واحد پول', 'novinpalpaiddownload') . ':</th>
										<td>
											<select name="novinpalpaiddownload_currency" id="novinpalpaiddownload_currency"' . (!in_array('curl', get_loaded_extensions()) ? ' disabled="disabled"' : '') . '>');

        for ($i = 0; $i < sizeof($this->novinpal_currency_list); $i++) {

            echo '<option value="' . $this->novinpal_currency_list[$i] . '"' . ($this->novinpal_currency_list[$i] == $this->options['novinpal_currency'] ? ' selected="selected"' : '') . '>' . $this->novinpal_currency_list[$i] . '</option>';
        }
        print('</select>
											<br /><em>' . __('نوع واحد پول مورد نظر خود را تعیین نمایید.', 'novinpalpaiddownload') . '</em>
										</td>
									</tr>
								</table>
								<div class="alignright">
									<input type="submit" class="paiddownoads_button button-primary" name="submit" value="' . __('ذخیره تنظیمات', 'novinpalpaiddownload') . ' »">
								</div>
								<br class="clear">
							</div>
						</div>
					</div>
				</div>
			</div>
			</form>
		</div>');
    }

    function novinpal_admin_files()
    {
        global $wpdb;

        $search_query = isset($_GET["s"]) ? trim(stripslashes($_GET["s"])) : "";

        $tmp = $wpdb->get_row("SELECT COUNT(*) AS total FROM " . $wpdb->prefix . "pd_files WHERE deleted = '0'  " . ((strlen($search_query) > 0) ? "and filename_original LIKE '%" . addslashes($search_query) . "%' OR deleted = '0' and  title LIKE '%" . addslashes($search_query) . "%'" : ""), ARRAY_A);
        $total = $tmp["total"];
        $totalPages = ceil($total / NOVINPAL_PD_RECORDS_PER_PAGE);

        if ($totalPages == 0) {

            $totalPages = 1;
        }

        $page = isset($_GET["p"]) ? intval($_GET["p"]) : 1;

        if ($page < 1 || $page > $totalPages) {

            $page = 1;
        }

        $switcher = $this->novinpal_page_switcher(get_bloginfo("wpurl") . "/wp-admin/admin.php?page=novinpal-paid-download-files" . ((strlen($search_query) > 0) ? "&s=" . rawurlencode($search_query) : ""), $page, $totalPages);

        $sql = "SELECT * FROM " . $wpdb->prefix . "pd_files WHERE deleted = '0' " . ((strlen($search_query) > 0) ? "and filename_original LIKE '%" . addslashes($search_query) . "%' OR deleted = '0' and  title LIKE '%" . addslashes($search_query) . "%'" : "") . " ORDER BY registered DESC LIMIT " . (($page - 1) * NOVINPAL_PD_RECORDS_PER_PAGE) . ", " . NOVINPAL_PD_RECORDS_PER_PAGE;
        $rows = $wpdb->get_results($sql, ARRAY_A);
        $message = '';

        if (!empty($this->error)) {

            $message = "<div class='error'><p>" . $this->error . "</p></div>";
        }

        if (!empty($this->info)) {

            $message = "<div class='updated'><p>" . $this->info . "</p></div>";
        }

        print ('<div class="wrap admin_novinpalpaiddownload_wrap">
                    <div id="icon-upload" class="icon32"><br/></div><h2>' . __('پرداخت نوین‌پال - فایل ها', 'novinpalpaiddownload') . '</h2><br/>
                    ' . $message . '
                        <form action="' . get_bloginfo("wpurl") . '/wp-admin/admin.php" method="get" style="margin-bottom: 10px;">
                            <input type="hidden" name="page" value="novinpal-paid-download-files" />
                            ' . __('جستجو :', 'novinpalpaiddownload') . ' <input type="text" name="s" value="' . htmlspecialchars($search_query, ENT_QUOTES) . '">
                            <input type="submit" class="button-secondary action" value="' . __('جستجو', 'novinpalpaiddownload') . '" />
                            ' . ((strlen($search_query) > 0) ? '<input type="button" class="button-secondary action" value="' . __('برگشت به حالت لیست', 'novinpalpaiddownload') . '" onclick="window.location.href=\'' . get_bloginfo("wpurl") . '/wp-admin/admin.php?page=novinpal-paid-download-files\';" />' : '') . '
                        </form>
                        <div class="novinpalpaiddownload_buttons"><a class="button" href="' . get_bloginfo("wpurl") . '/wp-admin/admin.php?page=novinpal-paid-download-add">' . __('بارگذاری فایل جدید', 'novinpalpaiddownload') . '</a></div>
                        <div class="novinpalpaiddownload_pageswitcher">' . $switcher . '</div>
                        <table class="novinpalpaiddownload_files">
                            <tr>
                                <th>' . __('فایل', 'novinpalpaiddownload') . '</th>
                                <th style="width: 190px;">' . __('کد فایل', 'novinpalpaiddownload') . '</th>
                                <th style="width: 90px;">' . __('مبلغ', 'novinpalpaiddownload') . '</th>
                                <th style="width: 90px;">' . __('تعداد فروش', 'novinpalpaiddownload') . '</th>
                                <th style="width: 130px;">' . __('عملیات', 'novinpalpaiddownload') . '</th>
                            </tr>');

        if (sizeof($rows) > 0) {

            foreach ($rows as $row) {

                $sql = "SELECT COUNT(id) AS sales FROM " . $wpdb->prefix . "pd_transactions WHERE file_id = '" . $row["id"] . "' AND (payment_status = '100')";
                $sales = $wpdb->get_row($sql, ARRAY_A);

                print ('<tr>
                            <td><strong>' . $row['title'] . '</strong><br /><em style="font-size: 12px; line-height: 14px;">' . htmlspecialchars($row['filename_original'], ENT_QUOTES) . '</em></td>
                            <td dir="ltr" style="direction:ltr; text-align:center">[novinpalpaiddownload id="' . $row['id'] . '"]</td>
                            <td style="text-align: right;">' . number_format($row['price'], 0) . ' ' . $row['currency'] . '</td>
                            <td style="text-align: right;">' . intval($sales["sales"]) . ' / ' . (($row['available_copies'] == 0) ? '&infin;' : $row['available_copies']) . '</td>
                            <td style="text-align: center;">
                                <a href="' . get_bloginfo("wpurl") . '/wp-admin/admin.php?page=novinpal-paid-download-add&id=' . $row['id'] . '" title="' . __('ویرایش جزئیات', 'novinpalpaiddownload') . '"><img src="' . plugins_url('/images/edit.png', __FILE__) . '" alt="' . __('ویرایش جزئیات', 'novinpalpaiddownload') . '" border="0"></a>
                                <a href="' . get_bloginfo("wpurl") . '/wp-admin/admin.php?page=novinpal-paid-download-add-link&fid=' . $row['id'] . '" title="' . __('ایجاد لینک دانلود', 'novinpalpaiddownload') . '"><img src="' . plugins_url('/images/downloadlink.png', __FILE__) . '" alt="' . __('ایجاد لینک دانلود', 'novinpalpaiddownload') . '" border="0"></a>
                                <a href="' . get_bloginfo("wpurl") . '/wp-admin/admin.php?page=novinpal-paid-download-links&fid=' . $row['id'] . '" title="' . __('لینک های دانلود ایجاد شده', 'novinpalpaiddownload') . '"><img src="' . plugins_url('/images/linkhistory.png', __FILE__) . '" alt="' . __('لینک های دانلود ایجاد شده', 'novinpalpaiddownload') . '" border="0"></a>
                                <a href="' . get_bloginfo("wpurl") . '/wp-admin/admin.php?page=novinpal-paid-download-transactions&fid=' . $row['id'] . '" title="' . __('تراکنش های پرداختی', 'novinpalpaiddownload') . '"><img src="' . plugins_url('/images/transactions.png', __FILE__) . '" alt="' . __('تراکنش های پرداختی', 'novinpalpaiddownload') . '" border="0"></a>
                                <a href="' . get_bloginfo("wpurl") . '/?novinpalpaiddownload_id=' . $row['id'] . '" title="' . __('دانلود فایل', 'novinpalpaiddownload') . '"><img src="' . plugins_url('/images/download01.png', __FILE__) . '" alt="' . __('دانلود فایل', 'novinpalpaiddownload') . '" border="0"></a>
                                <a href="' . get_bloginfo("wpurl") . '/wp-admin/admin.php?ak_action=novinpalpaiddownload_delete&id=' . $row['id'] . '" title="' . __('حذف فایل', 'novinpalpaiddownload') . '" onclick="return novinpalpaiddownload_submitOperation();"><img src="' . plugins_url('/images/delete.png', __FILE__) . '" alt="' . __('حذف فایل', 'novinpalpaiddownload') . '" border="0"></a>
                            </td>
                        </tr>');
            }

        } else {

            print ('<tr>
                        <td colspan="5" style="padding: 20px; text-align: center;">' . ((strlen($search_query) > 0) ? __('هیچ نتیجه ای یافت نشد', 'novinpalpaiddownload') . ' "<strong>' . htmlspecialchars($search_query, ENT_QUOTES) . '</strong>"' : __('هیچ فایلی یافت نشد.', 'novinpalpaiddownload')) . '</td>
                    </tr>');
        }

        print ('</table>
                    <div class="novinpalpaiddownload_buttons"><a class="button" href="' . get_bloginfo("wpurl") . '/wp-admin/admin.php?page=novinpal-paid-download-add">' . __('بارگذاری فایل جدید', 'novinpalpaiddownload') . '</a></div>
                    <div class="novinpalpaiddownload_pageswitcher">' . $switcher . '</div>
                    <div class="novinpalpaiddownload_legend">
                    <strong>' . __('راهنما:', 'novinpalpaiddownload') . '</strong>
                        <p><img src="' . plugins_url('/images/edit.png', __FILE__) . '" alt="' . __('ویرایش جزئیات', 'novinpalpaiddownload') . '" border="0"> ' . __('ویرایش جزئیات', 'novinpalpaiddownload') . '</p>
                        <p><img src="' . plugins_url('/images/downloadlink.png', __FILE__) . '" alt="' . __('ایجاد لینک دانلود', 'novinpalpaiddownload') . '" border="0"> ' . __('ایجاد لینک دانلود', 'novinpalpaiddownload') . '</p>
                        <p><img src="' . plugins_url('/images/linkhistory.png', __FILE__) . '" alt="' . __('لینک های دانلود ایجاد شده', 'novinpalpaiddownload') . '" border="0"> ' . __('لینک های دانلود ایجاد شده', 'novinpalpaiddownload') . '</p>
                        <p><img src="' . plugins_url('/images/transactions.png', __FILE__) . '" alt="' . __('تراکنش های پرداختی', 'novinpalpaiddownload') . '" border="0"> ' . __('تراکنش های پرداختی', 'novinpalpaiddownload') . '</p>
                        <p><img src="' . plugins_url('/images/download01.png', __FILE__) . '" alt="' . __('دانلود فایل', 'novinpalpaiddownload') . '" border="0"> ' . __('دانلود فایل', 'novinpalpaiddownload') . '</p>
                        <p><img src="' . plugins_url('/images/delete.png', __FILE__) . '" alt="' . __('حذف فایل', 'novinpalpaiddownload') . '" border="0"> ' . __('حذف فایل', 'novinpalpaiddownload') . '</p>
                    </div>
                </div>');
    }

    function novinpal_admin_add_file()
    {
        global $wpdb;

        unset($id);

        $file_title = '';
        $file_name = '';
        $file_uploaded = '';
        $file_price = '';
        $file_currency = '';
        $file_available_copies = '';
        $file_license_url = '';

        if (isset($_GET["id"]) && !empty($_GET["id"])) {

            $id = intval($_GET["id"]);
            $file_details = $wpdb->get_row("SELECT * FROM " . $wpdb->prefix . "pd_files WHERE id = '" . $id . "' AND deleted = '0'", ARRAY_A);
            $file_title = htmlspecialchars($file_details['title'], ENT_QUOTES);
            $file_name = $file_details['filename'];
            $file_uploaded = $file_details['uploaded'];
            $file_price = $file_details['price'];
            $file_currency = $file_details['currency'];
            $file_available_copies = $file_details['available_copies'];
            $file_license_url = $file_details['license_url'];

            if (intval($file_details["id"]) == 0) {

                unset($id);
            }
        }

        $message = '';
        if (!empty($this->error)) {

            $message = "<div class='error'><p>" . $this->error . "</p></div>";
        } else if (!empty($this->info)) {

            $message = "<div class='updated'><p>" . $this->info . "</p></div>";
        }

        if (file_exists(ABSPATH . 'wp-content/uploads/paid-download/files') && is_dir(ABSPATH . 'wp-content/uploads/paid-download/files')) {

            $dir_content = scandir(ABSPATH . 'wp-content/uploads/paid-download/files');

            for ($i = 0; $i < sizeof($dir_content); $i++) {

                if ($dir_content[$i] != "." &&
                    $dir_content[$i] != ".." &&
                    $dir_content[$i] != "index.html" &&
                    $dir_content[$i] != ".htaccess" &&
                    is_file(ABSPATH . 'wp-content/uploads/paid-download/files/' . $dir_content[$i])) {

                    $files[] = $dir_content[$i];
                }
            }
        }

        print ('<div class="wrap admin_novinpalpaiddownload_wrap">
                    <div id="icon-options-general" class="icon32"><br/></div><h2>' . (!empty($id) ? __('پرداخت نوین‌پال - ویرایش فایل', 'novinpalpaiddownload') : __('پرداخت نوین‌پال - بارگذاری فایل جدید', 'novinpalpaiddownload')) . '</h2>
                    ' . $message . '
                    <form enctype="multipart/form-data" method="post" style="margin: 0px" action="' . get_bloginfo('wpurl') . '/wp-admin/admin.php">
                    <div class="postbox-container" style="width: 100%;">
                        <div class="metabox-holder">
                            <div class="meta-box-sortables ui-sortable">
                                <div class="postbox">
                                    <h3 class="hndle" style="cursor: default;"><span>' . (!empty($id) ? __('ویرایش فایل', 'novinpalpaiddownload') : __('بارگذاری فایل جدید', 'novinpalpaiddownload')) . '</span></h3>
                                    <div class="inside">
                                        <table class="novinpalpaiddownload_useroptions">
                                            <tr>
                                                <th>' . __('عنوان', 'novinpalpaiddownload') . ':</th>
                                                <td><input type="text" name="novinpalpaiddownload_title" id="novinpalpaiddownload_title" value="' . $file_title . '" class="widefat"><br /><em>' . __('لطفا عنوان فایل خود را مشخص نمایید، در صورت خالی گذاشتن این فیلد نام فایل اصلی به انتخاب خواهد شد.', 'novinpalpaiddownload') . '</em></td>
                                            </tr>
                                            <tr>
                                                <th>' . __('فایل', 'novinpalpaiddownload') . ':</th>
                                                <td>
        
                                                <div class="container-tab">
        
                                                    <ul class="tabs">
                                                        <li class="tab-link current" data-tab="tab-1" onclick="changeTab(this)">بارگذاری فایل</li>
                                                        <li class="tab-link" data-tab="tab-2" onclick="changeTab(this)">انتخاب از فایل ها موجود</li>
                                                        <li class="tab-link" data-tab="tab-3" onclick="changeTab(this)">لینک به فایل</li>
                                                    </ul>
        
                                                    <div id="tab-1" class="tab-content current">
                                                        <input type="file" name="novinpalpaiddownload_file" id="novinpalpaiddownload_file" class="widefat"><br /><em>' . __('انتخاب فایل برای بارگذاری', 'novinpalpaiddownload') . '</em>
                                                    </div>
                                                    <div id="tab-2" class="tab-content">
                                                        <select name="novinpalpaiddownload_fileselector" id="novinpalpaiddownload_fileselector">
                                                        <option value="">-- ' . __('انتخاب از فایل های موجود', 'novinpalpaiddownload') . ' --</option>');

        if (!empty($files)) {

            for ($i = 0; $i < sizeof($files); $i++) {

                echo '<option value="' . htmlspecialchars($files[$i], ENT_QUOTES) . '"' . ($files[$i] == $file_name ? ' selected="selected"' : '') . '>' . htmlspecialchars($files[$i], ENT_QUOTES) . '</option>';
            }
        }
        print('</select><br/><em>' . __('شما می توانید یک فایل را از مسیر <strong>/wp-content/uploads/paid-download/files/</strong> انتخاب و یا نسبت به بارگذاری فایل اقدام نمایید.', 'novinpalpaiddownload') . '</em><br /><br />
                                                                                </div>
                                                                                <div id="tab-3" class="tab-content">
                                                                                     لینک دانلود فایل: <br><br>
                                                                                     <input type="text" name="novinpalpaiddownload_filelink" id="novinpalpaiddownload_filelink" value="' . ($file_uploaded == 2 ? $file_name : "") . '" class="widefat enput">
                                                                                     <br /><em>مسیر فایل را به صورت کامل جهت هدایت کاربر برای دانلود وارد نمایید ،&nbsp;مثال : http://www.mydownloadhost.com/files/filename.zip</em>
                                                                                </div>
                                                                                <input name="novinpalpaiddownload_filetype" id="novinpalpaiddownload_filetype" type="hidden" value="' . (isset($_GET['ty']) ? $_GET['ty'] : ($file_uploaded == 2 ? 'tab-3' : (!empty($file_uploaded) ? 'tab-2' : 'tab-1'))) . '" />
                                                                            </div>
                                                                            </td>
                                                                        </tr>
                                                                        <tr>
                                                                            <th>' . __('مبلغ', 'novinpalpaiddownload') . ':</th>
                                                                            <td>
                                                                                <input type="text" name="novinpalpaiddownload_price" id="novinpalpaiddownload_price" value="' . (!empty($id) ? number_format($file_price, 0, '.', '') : '0') . '" style="width: 80px; text-align: right;">
                                                                                <select name="novinpalpaiddownload_currency" style="vertical-align: inherit; height:26px;" id="novinpalpaiddownload_currency" onchange="novinpalpaiddownload_supportedmethods();">');
        foreach ($this->currency_list as $currency) {

            echo '<option value="' . $currency . '"' . ($currency == $file_currency ? ' selected="selected"' : '') . '>' . $currency . '</option>';
        }
        print('</select>
                                                                                <label id="novinpalpaiddownload_supported" style="color: green; display:none"></label>
                                                                                <br /><em>' . __('مبلغ مورد نظر جهت خرید فایل را تعیین نمایید، ورود مبلغ 0 به معنی رایگان بودن فایل خواهد بود.', 'novinpalpaiddownload') . '</em>
                                                                            </td>
                                                                        </tr>
                                                                        <tr>
                                                                            <th>' . __('تعداد موجود', 'novinpalpaiddownload') . ':</th>
                                                                            <td><input type="text" name="novinpalpaiddownload_available_copies" id="novinpalpaiddownload_available_copies" value="' . (!empty($id) ? intval($file_available_copies) : '0') . '" style="width: 80px; text-align: right;"><br /><em>' . __('تعداد موجود جهت فروش فایل را تعیین نمایید. پس از رسیدن فروش فایل به این سقف کلید خرید غیر فعال خواهد شد. خالی گذاشتن و یا مقدار 0 برای این فیلد به معنی تعداد نامحدود است. در صورتی که محدودیتی در فروش ندارید این گزینه را خالی بگذارید.', 'novinpalpaiddownload') . '</em></td>
                                                                        </tr>
                                                                        <tr>
                                                                            <th>' . __('مسیر دریافت لایسنس', 'novinpalpaiddownload') . ':</th>
                                                                            <td><input type="text" name="novinpalpaiddownload_license_url" id="novinpalpaiddownload_license_url" value="' . htmlspecialchars($file_license_url, ENT_QUOTES) . '" class="widefat enput"' . (!in_array('curl', get_loaded_extensions()) ? ' readonly="readonly"' : '') . '><br /><em>' . __('در صورتی که استفاده از این فایل نیازمند دریافت لایسنس است. پس از پرداخت موفقیت آمیز اطلاعات خرید نوین‌پال به این مسیر ارسال می شود. سپس محتوای برگشتی از این مسیر در  <strong>متن ایمیل خرید موفق</strong> جایگزین فیلد {license_info} خواهد شد. در صورتی که فایل شما بدون لایسنس است از این فیلد صرف نظر نمایید. استفاده از این گزینه نیازمند فعال بودن CURL بر روی سرور هاست است.', 'novinpalpaiddownload') . '</em></td>
                                                                        </tr>
                                                                    </table>
                                                                    <div class="alignright">
                                                                    <input type="hidden" name="ak_action" value="novinpalpaiddownload_update_file" />
                                                                    ' . (!empty($id) ? '<input type="hidden" name="novinpalpaiddownload_id" value="' . $id . '" />' : '') . '
                                                                    <input type="submit" class="paiddownoads_button button-primary" name="submit" value="' . __('ذخیره اطلاعات', 'novinpalpaiddownload') . ' »">
                                                                    </div>
                                                                    <br class="clear">
                                                                </div>
                                                            </div>
                                                        </div>
                                                    </div>
                                                </div>
                                                </form>
                                                <script type="text/javascript">
                                                    function novinpalpaiddownload_supportedmethods() {
                                                        let novinpal_currencies = new Array("' . implode('", "', $this->novinpal_currency_list) . '");
                                                        let currency = jQuery("#novinpalpaiddownload_currency").val();
                                                        let supported = "";
                                                        
                                                        if (jQuery.inArray(currency, novinpal_currencies) >= 0) {
                                                        
                                                            supported = "novinpal, ";
                                                        }
                                                        
                                                        supported = supported + "InterKassa";
                                                        jQuery("#novinpalpaiddownload_supported").html("' . __('Supported payment methods:', 'novinpalpaiddownload') . ' " + supported);
                                                    }
                                                    novinpalpaiddownload_supportedmethods();
                                    
                                                    function changeTab(tab){
                                    
                                                        let tab_id = jQuery(tab).attr("data-tab");
                                    
                                                        jQuery("ul.tabs li").removeClass("current");
                                                        jQuery(".tab-content").removeClass("current");
                                    
                                                        jQuery(tab).addClass("current");
                                                        jQuery("#"+tab_id).addClass("current");
                                                        jQuery("#novinpalpaiddownload_filetype").val(tab_id);
                                    
                                                    }
                                                    
                                                    changeTab(jQuery("li[data-tab=\'"+jQuery("#novinpalpaiddownload_filetype").val()+"\'"));
                                                </script>
                                            </div>');
    }

    function novinpal_admin_links()
    {
        global $wpdb;

        $file_id = isset($_GET["fid"]) ? intval(trim(stripslashes($_GET["fid"]))) : 0;

        $tmp = $wpdb->get_row("SELECT COUNT(*) AS total FROM " . $wpdb->prefix . "pd_downloadlinks WHERE deleted = '0'" . ($file_id > 0 ? " AND file_id = '" . $file_id . "'" : ""), ARRAY_A);
        $total = $tmp["total"];
        $totalPages = ceil($total / NOVINPAL_PD_RECORDS_PER_PAGE);

        if ($totalPages == 0) {

            $totalPages = 1;
        }

        $page = isset($_GET["p"]) ? intval($_GET["p"]) : 1;

        if ($page < 1 || $page > $totalPages) {

            $page = 1;
        }

        $switcher = $this->novinpal_page_switcher(get_bloginfo("wpurl") . "/wp-admin/admin.php?page=novinpal-paid-download-links" . ($file_id > 0 ? '&fid=' . $file_id : ''), $page, $totalPages);

        $sql = "SELECT t1.*, t2.title AS file_title FROM " . $wpdb->prefix . "pd_downloadlinks t1 LEFT JOIN " . $wpdb->prefix . "pd_files t2 ON t2.id = t1.file_id WHERE t1.deleted = '0'" . ($file_id > 0 ? " AND file_id = '" . $file_id . "'" : "") . " ORDER BY t1.created DESC LIMIT " . (($page - 1) * NOVINPAL_PD_RECORDS_PER_PAGE) . ", " . NOVINPAL_PD_RECORDS_PER_PAGE;
        $rows = $wpdb->get_results($sql, ARRAY_A);

        $message = '';
        if (!empty($this->error)) {

            $message = "<div class='error'><p>" . $this->error . "</p></div>";
        }

        if (!empty($this->info)) {

            $message = "<div class='updated'><p>" . $this->info . "</p></div>";
        }

        print ('<div class="wrap admin_novinpalpaiddownload_wrap">
                    <div id="icon-upload" class="icon32"><br /></div><h2>' . __('پرداخت نوین‌پال - لینک های دریافت', 'novinpalpaiddownload') . '</h2><br />
                    ' . $message . '
                    <div class="novinpalpaiddownload_buttons"><a class="button" href="' . get_bloginfo("wpurl") . '/wp-admin/admin.php?page=novinpal-paid-download-add-link' . ($file_id > 0 ? '&fid=' . $file_id : '') . '">' . __('اضافه کردن لینک جدید', 'novinpalpaiddownload') . '</a></div>
                    <div class="novinpalpaiddownload_pageswitcher">' . $switcher . '</div>
                    <table class="novinpalpaiddownload_files">
                    <tr>
                        <th>' . __('لینک دانلود', 'novinpalpaiddownload') . '</th>
                        <th style="width: 160px;">' . __('صاحب', 'novinpalpaiddownload') . '</th>
                        <th style="width: 160px;">' . __('فایل', 'novinpalpaiddownload') . '</th>
                        <th style="width: 80px;">' . __('منبع', 'novinpalpaiddownload') . '</th>
                        <th style="width: 50px;">' . __('حذف', 'novinpalpaiddownload') . '</th>
                    </tr>');

        if (sizeof($rows) > 0) {

            foreach ($rows as $row) {

                if (time() <= $row["created"] + 24 * 3600 * $this->options['link_lifetime']) {

                    $expired = "منقضی در " . $this->novinpal_period_to_string($row["created"] + 24 * 3600 * $this->options['link_lifetime'] - time()) . " دیگر";
                    $bg_color = "#FFFFFF";

                } else {

                    $expired = "";
                    $bg_color = "#F0F0F0";
                }

                print ('<tr style="background-color: ' . $bg_color . ';">
                            <td><input type="text" class="widefat" onclick="this.focus();this.select();" readonly="readonly" dir="ltr" value="' . get_bloginfo('wpurl') . '/?novinpalpaiddownload_key=' . $row["download_key"] . '">' . (!empty($expired) ? '<br /><em>' . $expired . '</em>' : '') . '</td>
                            <td>' . htmlspecialchars($row['owner'], ENT_QUOTES) . '</td>
                            <td>' . (!empty($row['file_title']) ? htmlspecialchars($row['file_title'], ENT_QUOTES) : '-') . '</td>
                            <td>' . htmlspecialchars($row['source'] == 'purchasing' ? 'فروش' : 'دستی', ENT_QUOTES) . '</td>
                            <td style="text-align: center;">
                                <a href="' . get_bloginfo("wpurl") . '/wp-admin/admin.php?ak_action=novinpalpaiddownload_delete_link&id=' . $row['id'] . '" title="' . __('حذف لینک دریافت', 'novinpalpaiddownload') . '" onclick="return novinpalpaiddownload_submitOperation();"><img src="' . plugins_url('/images/delete.png', __FILE__) . '" alt="' . __('Delete download link', 'novinpalpaiddownload') . '" border="0"></a>
                            </td>
                        </tr>');
            }
        } else {

            print ('<tr>
                        <td colspan="5" style="padding: 20px; text-align: center;">' . __('هیچ لینک دریافتی موجود نمی باشد', 'novinpalpaiddownload') . '</td>
                    </tr>');
        }

        print ('</table>
				    <div class="novinpalpaiddownload_buttons"><a class="button" href="' . get_bloginfo("wpurl") . '/wp-admin/admin.php?page=novinpal-paid-download-add-link' . ($file_id > 0 ? '&fid=' . $file_id : '') . '">' . __('اضافه کردن لینک جدید', 'novinpalpaiddownload') . '</a></div>
                        <div class="novinpalpaiddownload_pageswitcher">' . $switcher . '</div>
                        <div class="novinpalpaiddownload_legend">
                            <strong>' . __('راهنما :', 'novinpalpaiddownload') . '</strong>
                            <p><img src="' . plugins_url('/images/delete.png', __FILE__) . '" alt="' . __('حذف لینک دریافت', 'novinpalpaiddownload') . '" border="0"> ' . __('حذف لینک دریافت', 'novinpalpaiddownload') . '</p>
                            <br/>
                            <div style="width: 14px; height: 14px; float: right; border: 1px solid #CCC; margin: 0px 10px 0px 0px; background-color: #FFFFFF;""></div> ' . __('لینک های فعال', 'novinpalpaiddownload') . '<br />
                            <div style="width: 14px; height: 14px; float: right; border: 1px solid #CCC; margin: 0px 10px 0px 0px; background-color: #F0F0F0;"></div> ' . __('لینک های منقضی', 'novinpalpaiddownload') . '<br />
                        </div>
                </div>');
    }

    function novinpal_admin_add_link()
    {
        global $wpdb;

        $file_id = isset($_GET["fid"]) ? intval(trim(stripslashes($_GET["fid"]))) : 0;

        $message = '';
        if (!empty($this->error)) {

            $message = "<div class='error'><p>" . $this->error . "</p></div>";
        } else if (!empty($this->info)) {

            $message = "<div class='updated'><p>" . $this->info . "</p></div>";
        }

        $sql = "SELECT * FROM " . $wpdb->prefix . "pd_files WHERE deleted = '0' ORDER BY registered DESC";
        $files = $wpdb->get_results($sql, ARRAY_A);

        if (empty($files)) {

            print ('<div class="wrap admin_novinpalpaiddownload_wrap">
                        <div id="icon-options-general" class="icon32"><br /></div><h2>' . __('پرداخت نوین‌پال - اضافه کردن لینک دریافت', 'novinpalpaiddownload') . '</h2>
                        <div class="error"><p>' . __('ابتدا یک فایل را جهت ایجاد لینک به سیستم اضافه نمایید.', 'novinpalpaiddownload') . '</p></div>
                    </div>');
            return;
        }

        print ('<div class="wrap admin_novinpalpaiddownload_wrap">
                    <div id="icon-options-general" class="icon32"><br /></div><h2>' . __('پرداخت نوین‌پال - اضافه کردن لینک دریافت', 'novinpalpaiddownload') . '</h2>
                    ' . $message . '
                    <form enctype="multipart/form-data" method="post" style="margin: 0px" action="' . get_bloginfo('wpurl') . '/wp-admin/admin.php">
                    <div class="postbox-container" style="width: 100%;">
                        <div class="metabox-holder">
                            <div class="meta-box-sortables ui-sortable">
                                <div class="postbox">
                                    <h3 class="hndle" style="cursor: default;"><span>' . __('اضافه کردن لینک دریافت', 'novinpalpaiddownload') . '</span></h3>
                                    <div class="inside">
                                        <table class="novinpalpaiddownload_useroptions">
                                            <tr>
                                                <th>' . __('فایل', 'novinpalpaiddownload') . ':</th>
                                                <td>
                                                    <select name="novinpalpaiddownload_fileselector" id="novinpalpaiddownload_fileselector">
                                                        <option value="">-- ' . __('انتخاب فایل', 'novinpalpaiddownload') . ' --</option>');
        foreach ($files as $file) {
            echo '<option value="' . $file["id"] . '"' . ($file["id"] == $file_id ? 'selected="selected"' : '') . '>' . htmlspecialchars($file["title"], ENT_QUOTES) . '</option>';
        }
        print('</select><br /><em>' . __('لطفا یک فایل را انتخاب نمایید .', 'novinpalpaiddownload') . '</em>
                                                                            </td>
                                                                        </tr>
                                                                        <tr>
                                                                            <th>' . __('صاحب لینک', 'novinpalpaiddownload') . ':</th>
                                                                            <td><input type="text" name="novinpalpaiddownload_link_owner" id="novinpalpaiddownload_link_owner" value="" style="width: 50%;"><br /><em>' . __('لطفا یک آدرس ایمیل را جهت ایجاد لینک دریافت وارد نمایید.', 'novinpalpaiddownload') . '</em></td>
                                                                        </tr>
                                                                    </table>
                                                                    <div class="alignright">
                                                                    <input type="hidden" name="ak_action" value="novinpalpaiddownload_update_link" />
                                                                    <input type="submit" class="paiddownoads_button button-primary" name="submit" value="' . __('ذخیره اطلاعات', 'novinpalpaiddownload') . ' »">
                                                                    </div>
                                                                    <br class="clear">
                                                                </div>
                                                            </div>
                                                        </div>
                                                    </div>
                                                </div>
                                                </form>
                                            </div>');
    }

    function novinpal_admin_transactions()
    {

        global $wpdb;

        $search_query = isset($_GET["s"]) ? trim(stripslashes($_GET["s"])) : "";
        $file_id = isset($_GET["fid"]) ? intval(trim(stripslashes($_GET["fid"]))) : 0;

        $tmp = $wpdb->get_row("SELECT COUNT(*) AS total FROM " . $wpdb->prefix . "pd_transactions WHERE id > 0" . ($file_id > 0 ? " AND file_id = '" . $file_id . "'" : "") . ((strlen($search_query) > 0) ? " AND (payer_name LIKE '%" . addslashes($search_query) . "%' OR payer_email LIKE '%" . addslashes($search_query) . "%')" : ""), ARRAY_A);
        $total = $tmp["total"];
        $totalPages = ceil($total / NOVINPAL_PD_RECORDS_PER_PAGE);

        if ($totalPages == 0) {

            $totalPages = 1;
        }

        $page = isset($_GET["p"]) ? intval($_GET["p"]) : 1;

        if ($page < 1 || $page > $totalPages) {

            $page = 1;
        }

        $switcher = $this->novinpal_page_switcher(get_bloginfo("wpurl") . "/wp-admin/admin.php?page=novinpal-paid-download-transactions" . ((strlen($search_query) > 0) ? "&s=" . rawurlencode($search_query) : "") . ($file_id > 0 ? "&fid=" . $file_id : ""), $page, $totalPages);

        $sql = "SELECT t1.*, t2.title AS file_title FROM " . $wpdb->prefix . "pd_transactions t1 LEFT JOIN " . $wpdb->prefix . "pd_files t2 ON t1.file_id = t2.id WHERE t1.id > 0" . ($file_id > 0 ? " AND t1.file_id = '" . $file_id . "'" : "") . ((strlen($search_query) > 0) ? " AND (t1.payer_name LIKE '%" . addslashes($search_query) . "%' OR t1.payer_email LIKE '%" . addslashes($search_query) . "%')" : "") . " ORDER BY t1.created DESC LIMIT " . (($page - 1) * NOVINPAL_PD_RECORDS_PER_PAGE) . ", " . NOVINPAL_PD_RECORDS_PER_PAGE;
        $rows = $wpdb->get_results($sql, ARRAY_A);

        print ('<div class="wrap admin_novinpalpaiddownload_wrap">
                    <div id="icon-edit-pages" class="icon32"><br /></div><h2>' . __('پرداخت نوین‌پال - پرداخت ها', 'novinpalpaiddownload') . '</h2><br />
                    <form action="' . get_bloginfo("wpurl") . '/wp-admin/admin.php" method="get" style="margin-bottom: 10px;">
                        <input type="hidden" name="page" value="novinpal-paid-download-transactions" />
                        ' . ($file_id > 0 ? '<input type="hidden" name="bid" value="' . $file_id . '" />' : '') . '
                        ' . __('جستجوی خریدار :', 'novinpalpaiddownload') . ' <input type="text" name="s" value="' . htmlspecialchars($search_query, ENT_QUOTES) . '">
                        <input type="submit" class="button-secondary action" value="' . __('جستجو', 'novinpalpaiddownload') . '" />
                        ' . ((strlen($search_query) > 0) ? '<input type="button" class="button-secondary action" value="' . __('برگشت به حالت لیست', 'novinpalpaiddownload') . '" onclick="window.location.href=\'' . get_bloginfo("wpurl") . '/wp-admin/admin.php?page=novinpal-paid-download-transactions' . ($file_id > 0 ? '&bid=' . $file_id : '') . '\';" />' : '') . '
                    </form>
                    <div class="novinpalpaiddownload_pageswitcher">' . $switcher . '</div>
                    <table class="novinpalpaiddownload_files">
                    <tr>
                        <th>' . __('فایل', 'novinpalpaiddownload') . '</th>
                        <th>' . __('خریدار', 'novinpalpaiddownload') . '</th>
                        <th style="width: 100px;">' . __('مبلغ', 'novinpalpaiddownload') . '</th>
                        <th style="width: 120px;">' . __('وضعیت', 'novinpalpaiddownload') . '</th>
                        <th style="width: 130px;">' . __('ایجاد', 'novinpalpaiddownload') . '*</th>
                    </tr>');

        if (sizeof($rows) > 0) {

            foreach ($rows as $row) {

                print ('<tr>
                            <td>' . htmlspecialchars($row['file_title'], ENT_QUOTES) . '</td>
                            <td>' . htmlspecialchars($row['payer_name'], ENT_QUOTES) . '<br /><em>' . htmlspecialchars($row['payer_email'], ENT_QUOTES) . '</em><br /><em>' . htmlspecialchars($row['payer_phone'], ENT_QUOTES) . '</em></td>
                            <td style="text-align: right;">' . number_format($row['gross'], 0, ".", "") . ' ' . $row['currency'] . '</td>
                            <td><a href="' . get_bloginfo("wpurl") . '/wp-admin/admin.php?ak_action=novinpalpaiddownload_transactiondetails&id=' . $row['id'] . '" class="thickbox" title="Transaction Details">' . $row["payment_status"] . '</a><br /><em>' . $row["transaction_type"] . '</em></td>
                            <td>' . date("Y-m-d H:i", $row["created"]) . '</td>
                        </tr>');
            }
        } else {

            print ('<tr>
                        <td colspan="5" style="padding: 20px; text-align: center;">' . ((strlen($search_query) > 0) ? __('هیچ نتیجه ای یافت نشد', 'novinpalpaiddownload') . ' "<strong>' . htmlspecialchars($search_query, ENT_QUOTES) . '</strong>"' : __('هیچ پرداختی یافت نشد .', 'novinpalpaiddownload')) . '</td>
                    </tr>');
        }

        print ('</table>
				<div class="novinpalpaiddownload_pageswitcher">' . $switcher . '</div>
			</div>');
    }

    function novinpal_admin_request_handler()
    {
        global $wpdb;

        if (!empty($_POST['ak_action'])) {

            switch ($_POST['ak_action']) {

                case 'novinpalpaiddownload_novinpal_update_settings':

                    $this->novinpal_populate_settings();
                    $this->options['enable_novinpal'] = "on";
                    $this->options['novinpal_address'] = isset($_POST["novinpalpaiddownload_novinpal_address"]) ? "on" : "off";
                    $this->options['handle_unverified'] = isset($_POST["novinpalpaiddownload_handle_unverified"]) ? "on" : "off";
                    $this->options['getphonenumber'] = !empty($_POST["novinpalpaiddownload_getphonenumber"]) ? "on" : "off";
                    $this->options['showdownloadlink'] = !empty($_POST["novinpalpaiddownload_showdownloadlink"]) ? "on" : "off";

                    $buy_now_image = "";
                    $errors_info = "";

                    if (is_uploaded_file($_FILES["novinpalpaiddownload_buy_now_image"]["tmp_name"])) {

                        $ext = strtolower(substr($_FILES["novinpalpaiddownload_buy_now_image"]["name"], strlen($_FILES["novinpalpaiddownload_buy_now_image"]["name"]) - 4));

                        if ($ext != ".jpg" && $ext != ".gif" && $ext != ".png") {

                            $errors[] = __('Custom "Buy Now" button has invalid image type', 'novinpalpaiddownload');
                        } else {

                            list($width, $height, $type, $attr) = getimagesize($_FILES["novinpalpaiddownload_buy_now_image"]["tmp_name"]);

                            if ($width > 600 || $height > 600) {

                                $errors[] = __('Custom "Buy Now" button has invalid image dimensions', 'novinpalpaiddownload');
                            } else {

                                $buy_now_image = "button_" . md5(microtime() . $_FILES["novinpalpaiddownload_buy_now_image"]["tmp_name"]) . $ext;

                                if (!move_uploaded_file($_FILES["novinpalpaiddownload_buy_now_image"]["tmp_name"], ABSPATH . "wp-content/uploads/paid-download/" . $buy_now_image)) {

                                    $errors[] = "Can't save uploaded image";
                                    $buy_now_image = "";

                                } else {

                                    if (!empty($this->options['buy_now_image']) &&
                                        file_exists(ABSPATH . "wp-content/uploads/paid-download/" . $this->options['buy_now_image']) &&
                                        is_file(ABSPATH . "wp-content/uploads/paid-download/" . $this->options['buy_now_image'])) {

                                        unlink(ABSPATH . "wp-content/uploads/paid-download/" . $this->options['buy_now_image']);
                                    }
                                }
                            }
                        }
                    }

                    if (!empty($buy_now_image)) {

                        $this->options['buy_now_image'] = $buy_now_image;
                    }

                    if ($this->options['buynow_type'] == "custom" && empty($this->options['buy_now_image'])) {

                        $this->options['buynow_type'] = "html";
                        $errors_info = __('Due to "Buy Now" image problem "Buy Now" button was set to Standard HTML button.', 'novinpalpaiddownload');
                    }

                    $errors = $this->novinpal_check_settings();
                    $this->novinpal_update_settings();

                    if (empty($errors_info) && $errors === true) {

                        header('Location: ' . get_bloginfo('wpurl') . '/wp-admin/admin.php?page=novinpal-paid-download&updated=true');
                    } else {

                        $message = "";

                        if (is_array($errors)) {

                            $message = __('در ثبت اطلاعات خطاهای زیر وجود دارد :', 'novinpalpaiddownload') . '<br />- ' . implode('<br />- ', $errors);
                        }

                        if (!empty($errors_info)) {

                            $message .= (empty($message) ? "" : "<br />") . $errors_info;
                        }

                        setcookie("novinpalpaiddownload_error", $message, time() + 30, "/", "." . str_replace("www.", "", $_SERVER["SERVER_NAME"]));
                        header('Location: ' . get_bloginfo('wpurl') . '/wp-admin/admin.php?page=novinpal-paid-download');
                    }
                    die();

                case 'novinpalpaiddownload_update_file':

                    if (isset($_POST["novinpalpaiddownload_id"]) && !empty($_POST["novinpalpaiddownload_id"])) {

                        $id = intval($_POST["novinpalpaiddownload_id"]);
                        $file_details = $wpdb->get_row("SELECT * FROM " . $wpdb->prefix . "pd_files WHERE id = '" . $id . "' AND deleted = '0'", ARRAY_A);

                        if (intval($file_details["id"]) == 0) {

                            unset($id);
                        }
                    }

                    $title = trim(stripslashes($_POST["novinpalpaiddownload_title"]));
                    $price = trim(stripslashes($_POST["novinpalpaiddownload_price"]));
                    $price = number_format(floatval($price), 2, '.', '');
                    $currency = trim(stripslashes($_POST["novinpalpaiddownload_currency"]));
                    $available_copies = trim(stripslashes($_POST["novinpalpaiddownload_available_copies"]));
                    $available_copies = intval($available_copies);
                    $file_selector = trim(stripslashes($_POST["novinpalpaiddownload_fileselector"]));
                    $file_link = trim(stripslashes($_POST["novinpalpaiddownload_filelink"]));
                    $filetype = trim(stripslashes($_POST["novinpalpaiddownload_filetype"]));

                    $license_url = trim(stripslashes($_POST["novinpalpaiddownload_license_url"]));

                    if (!preg_match('|^http(s)?://[a-z0-9-]+(.[a-z0-9-]+)*(:[0-9]+)?(/.*)?$|i', $license_url) || strlen($license_url) == 0) {

                        $license_url = "";
                    }

                    if ($filetype == "" || $filetype == "tab-1") {

                        if (is_uploaded_file($_FILES["novinpalpaiddownload_file"]["tmp_name"])) {

                            $uploaded = 1;

                            if (empty($title)) {

                                $title = $_FILES["novinpalpaiddownload_file"]["name"];
                            }

                            if ($file_details["uploaded"] == 1 &&
                                file_exists(ABSPATH . "wp-content/uploads/paid-download/files/" . $file_details["filename"]) &&
                                is_file(ABSPATH . "wp-content/uploads/paid-download/files/" . $file_details["filename"])) {

                                unlink(ABSPATH . "wp-content/uploads/paid-download/files/" . $file_details["filename"]);
                            }

                            $filename = $this->novinpal_get_filename(ABSPATH . 'wp-content/uploads/paid-download/files/', $_FILES["novinpalpaiddownload_file"]["name"]);
                            $filename_original = $_FILES["novinpalpaiddownload_file"]["name"];

                            if (!move_uploaded_file($_FILES["novinpalpaiddownload_file"]["tmp_name"], ABSPATH . "wp-content/uploads/paid-download/files/" . $filename)) {

                                setcookie("novinpalpaiddownload_error", __('Unable to save uploaded file on server', 'novinpalpaiddownload'), time() + 30, "/", "." . str_replace("www.", "", $_SERVER["SERVER_NAME"]));
                                header('Location: ' . get_bloginfo("wpurl") . '/wp-admin/admin.php?page=novinpal-paid-download-add' . (!empty($id) ? '&id=' . $id : '') . '&ty=' . $filetype);
                                exit;
                            }

                        } else {

                            setcookie("novinpalpaiddownload_error", __('خطا ! فایل مورد نظر خود را جهت بارگذاری انتخاب نمایید ', 'novinpalpaiddownload'), time() + 30, "/", "." . str_replace("www.", "", $_SERVER["SERVER_NAME"]));
                            header('Location: ' . get_bloginfo("wpurl") . '/wp-admin/admin.php?page=novinpal-paid-download-add' . (!empty($id) ? '&id=' . $id : '') . '&ty=' . $filetype);
                            exit;
                        }

                    } else if ($filetype == "tab-2") {

                        if ($file_selector != "" &&
                            file_exists(ABSPATH . "wp-content/uploads/paid-download/files/" . $file_selector) &&
                            is_file(ABSPATH . "wp-content/uploads/paid-download/files/" . $file_selector)) {

                            if (empty($title)) {

                                $title = $_FILES["novinpalpaiddownload_file"]["name"];
                            }

                            $filename = $file_selector;
                            $filename_original = $filename;

                            if (empty($title)) {

                                $title = $filename;
                            }

                            if ($file_selector == $file_details["filename"]) {

                                $uploaded = 1;
                                $filename_original = $file_details["filename_original"];
                            } else {

                                $uploaded = 0;
                                $filename_original = $filename;
                            }
                        } else {

                            setcookie("novinpalpaiddownload_error", __('خطا ! هیچ فایلی انتخاب نشده است', 'novinpalpaiddownload'), time() + 30, "/", "." . str_replace("www.", "", $_SERVER["SERVER_NAME"]));
                            header('Location: ' . get_bloginfo("wpurl") . '/wp-admin/admin.php?page=novinpal-paid-download-add' . (!empty($id) ? '&id=' . $id : '') . '&ty=' . $filetype);
                            exit;
                        }
                    } else if ($filetype == "tab-3") {

                        if ($file_link != "") {

                            if (preg_match("/\b(?:(?:https?|ftp):\/\/|www\.)[-a-z0-9+&@#\/%?=~_|!:,.;]*[-a-z0-9+&@#\/%=~_|]/i", $file_link)) {

                                if (empty($title)) {

                                    $title = 'بدون عنوان';
                                }

                                $uploaded = 2;
                                $filename_original = $file_link;
                                $filename = $file_link;
                            } else {

                                setcookie("novinpalpaiddownload_error", __('خطا ! مسیر فایل وارد شده صحیح نمی باشد', 'novinpalpaiddownload'), time() + 30, "/", "." . str_replace("www.", "", $_SERVER["SERVER_NAME"]));
                                header('Location: ' . get_bloginfo("wpurl") . '/wp-admin/admin.php?page=novinpal-paid-download-add' . (!empty($id) ? '&id=' . $id : '') . '&ty=' . $filetype);
                                exit;
                            }
                        } else {

                            setcookie("novinpalpaiddownload_error", __('خطا ! مسیر دانلود فایل وارد نشده است', 'novinpalpaiddownload'), time() + 30, "/", "." . str_replace("www.", "", $_SERVER["SERVER_NAME"]));
                            header('Location: ' . get_bloginfo("wpurl") . '/wp-admin/admin.php?page=novinpal-paid-download-add' . (!empty($id) ? '&id=' . $id : '') . '&ty=' . $filetype);
                            exit;
                        }
                    }

                    if (!empty($id)) {

                        $sql = "UPDATE " . $wpdb->prefix . "pd_files SET
							title = '" . esc_sql($title) . "',
							filename = '" . esc_sql($filename) . "',
							filename_original = '" . esc_sql($filename_original) . "',
							price = '" . $price . "',
							currency = '" . $currency . "',
							available_copies = '" . $available_copies . "',
							uploaded = '" . $uploaded . "',
							license_url = '" . esc_sql($license_url) . "'
							WHERE id = '" . $id . "'";

                        if ($wpdb->query($sql) !== false) {

                            setcookie("novinpalpaiddownload_info", __('فایل با موفقیت بارگذاری شد', 'novinpalpaiddownload'), time() + 30, "/", "." . str_replace("www.", "", $_SERVER["SERVER_NAME"]));
                            header('Location: ' . get_bloginfo("wpurl") . '/wp-admin/admin.php?page=novinpal-paid-download-files');
                        } else {

                            setcookie("novinpalpaiddownload_error", __('سرویس در دسترس نمی باشد', 'novinpalpaiddownload'), time() + 30, "/", "." . str_replace("www.", "", $_SERVER["SERVER_NAME"]));
                            header('Location: ' . get_bloginfo("wpurl") . '/wp-admin/admin.php?page=novinpal-paid-download-add' . (!empty($id) ? '&id=' . $id : ''));
                        }
                        exit;
                    } else {

                        $sql = "INSERT INTO " . $wpdb->prefix . "pd_files (
							title, filename, filename_original, price, currency, registered, available_copies, uploaded, license_url, deleted) VALUES (
							'" . esc_sql($title) . "',
							'" . esc_sql($filename) . "',
							'" . esc_sql($filename_original) . "',
							'" . $price . "',
							'" . $currency . "',
							'" . time() . "',
							'" . $available_copies . "',
							'" . $uploaded . "',
							'" . esc_sql($license_url) . "',
							'0'
							)";

                        if ($wpdb->query($sql) !== false) {

                            setcookie("novinpalpaiddownload_info", __('فایل با موفقیت اضافه شد', 'novinpalpaiddownload'), time() + 30, "/", "." . str_replace("www.", "", $_SERVER["SERVER_NAME"]));
                            header('Location: ' . get_bloginfo("wpurl") . '/wp-admin/admin.php?page=novinpal-paid-download-files');
                        } else {

                            setcookie("novinpalpaiddownload_error", __('سرویس در دسترس نمی باشد', 'novinpalpaiddownload'), time() + 30, "/", "." . str_replace("www.", "", $_SERVER["SERVER_NAME"]));
                            header('Location: ' . get_bloginfo("wpurl") . '/wp-admin/admin.php?page=novinpal-paid-download-add' . (!empty($id) ? '&id=' . $id : ''));
                        }
                        exit;
                    }
                    break;

                case 'novinpalpaiddownload_update_link':

                    $link_owner = trim(stripslashes($_POST["novinpalpaiddownload_link_owner"]));

                    if (!preg_match("/^[_a-z0-9-]+(\.[_a-z0-9-]+)*@[a-z0-9-]+(\.[a-z0-9-]+)*(\.[a-z]{2,4})$/i", $link_owner) || strlen($link_owner) == 0) {

                        setcookie("novinpalpaiddownload_error", __('ایمیل صاحب لینک به صورت صحیح وارد نشده است.', 'novinpalpaiddownload'), time() + 30, "/", "." . str_replace("www.", "", $_SERVER["SERVER_NAME"]));
                        header('Location: ' . get_bloginfo("wpurl") . '/wp-admin/admin.php?page=novinpal-paid-download-add-link');
                        exit;
                    }

                    $file_id = trim(stripslashes($_POST["novinpalpaiddownload_fileselector"]));
                    $file_details = $wpdb->get_row("SELECT * FROM " . $wpdb->prefix . "pd_files WHERE id = '" . $file_id . "' AND deleted = '0'", ARRAY_A);

                    if (intval($file_details["id"]) == 0) {

                        setcookie("novinpalpaiddownload_error", __('خطا در فراخوانی سرویس .', 'novinpalpaiddownload'), time() + 30, "/", "." . str_replace("www.", "", $_SERVER["SERVER_NAME"]));
                        header('Location: ' . get_bloginfo("wpurl") . '/wp-admin/admin.php?page=novinpal-paid-download-add-link');
                        exit;
                    }

                    $link = $this->novinpal_generate_downloadlink($file_details["id"], $link_owner, "manual");
                    setcookie("novinpalpaiddownload_info", __('لینک دریافت فایل با موفقیت ایجاد شد', 'novinpalpaiddownload'), time() + 30, "/", "." . str_replace("www.", "", $_SERVER["SERVER_NAME"]));
                    header('Location: ' . get_bloginfo("wpurl") . '/wp-admin/admin.php?page=novinpal-paid-download-links');
                    exit;
            }
        }

        if (!empty($_GET['ak_action'])) {

            switch ($_GET['ak_action']) {

                case 'novinpalpaiddownload_delete':

                    $id = intval($_GET["id"]);
                    $file_details = $wpdb->get_row("SELECT * FROM " . $wpdb->prefix . "pd_files WHERE id = '" . $id . "' AND deleted = '0'", ARRAY_A);

                    if (intval($file_details["id"]) == 0) {

                        setcookie("novinpalpaiddownload_error", __('Invalid service call', 'novinpalpaiddownload'), time() + 30, "/", "." . str_replace("www.", "", $_SERVER["SERVER_NAME"]));
                        header('Location: ' . get_bloginfo('wpurl') . '/wp-admin/admin.php?page=novinpal-paid-download-files');
                        die();
                    }

                    $sql = "UPDATE " . $wpdb->prefix . "pd_files SET deleted = '1' WHERE id = '" . $id . "'";
                    if ($wpdb->query($sql) !== false) {

                        if (file_exists(ABSPATH . "wp-content/uploads/paid-download/files/" . $file_details["filename"]) && is_file(ABSPATH . "wp-content/uploads/paid-download/files/" . $file_details["filename"])) {

                            $tmp_details = $wpdb->get_row("SELECT * FROM " . $wpdb->prefix . "pd_files WHERE filename = '" . $file_details["filename"] . "' AND deleted = '0'", ARRAY_A);

                            if (intval($tmp_details["id"]) == 0 && $file_details["uploaded"] == 1) {

                                unlink(ABSPATH . "wp-content/uploads/paid-download/files/" . $file_details["filename"]);
                            }
                        }

                        setcookie("novinpalpaiddownload_info", __('File successfully removed', 'novinpalpaiddownload'), time() + 30, "/", "." . str_replace("www.", "", $_SERVER["SERVER_NAME"]));
                    } else {

                        setcookie("novinpalpaiddownload_error", __('Invalid service call', 'novinpalpaiddownload'), time() + 30, "/", "." . str_replace("www.", "", $_SERVER["SERVER_NAME"]));
                    }

                    header('Location: ' . get_bloginfo('wpurl') . '/wp-admin/admin.php?page=novinpal-paid-download-files');
                    die();

                case 'novinpalpaiddownload_delete_link':

                    $id = intval($_GET["id"]);
                    $file_details = $wpdb->get_row("SELECT * FROM " . $wpdb->prefix . "pd_downloadlinks WHERE id = '" . $id . "' AND deleted = '0'", ARRAY_A);

                    if (intval($file_details["id"]) == 0) {

                        setcookie("novinpalpaiddownload_error", __('Invalid service call', 'novinpalpaiddownload'), time() + 30, "/", "." . str_replace("www.", "", $_SERVER["SERVER_NAME"]));
                        header('Location: ' . get_bloginfo('wpurl') . '/wp-admin/admin.php?page=novinpal-paid-download-links');
                        die();
                    }

                    $sql = "UPDATE " . $wpdb->prefix . "pd_downloadlinks SET deleted = '1' WHERE id = '" . $id . "'";

                    if ($wpdb->query($sql) !== false) {

                        setcookie("novinpalpaiddownload_info", __('Temporary download link successfully removed.', 'novinpalpaiddownload'), time() + 30, "/", "." . str_replace("www.", "", $_SERVER["SERVER_NAME"]));
                    } else {

                        setcookie("novinpalpaiddownload_error", __('Invalid service call.', 'novinpalpaiddownload'), time() + 30, "/", "." . str_replace("www.", "", $_SERVER["SERVER_NAME"]));
                    }

                    header('Location: ' . get_bloginfo('wpurl') . '/wp-admin/admin.php?page=novinpal-paid-download-links');
                    die();

                case 'novinpalpaiddownload_hidedonationbox':

                    $this->options['show_donationbox'] = NOVINPAL_PD_VERSION;
                    $this->novinpal_update_settings();
                    header('Location: ' . get_bloginfo('wpurl') . '/wp-admin/admin.php?page=novinpal-paid-download');
                    die();

                case 'novinpalpaiddownload_transactiondetails':

                    if (isset($_GET["id"]) && !empty($_GET["id"])) {

                        $id = intval($_GET["id"]);
                        $transaction_details = $wpdb->get_row("SELECT * FROM " . $wpdb->prefix . "pd_transactions WHERE id = '" . $id . "' AND deleted = '0'", ARRAY_A);
                        if (intval($transaction_details["id"]) != 0) {

                            echo '<html>
                                    <head>
                                        <title>Transaction Details</title>
                                    </head>
                                    <body>
                                        <table style="width: 100%;">';

                            $details = explode("&", $transaction_details["details"]);

                            foreach ($details as $param) {

                                $data = explode("=", $param, 2);

                                echo '<tr>
                                        <td style="width: 170px; font-weight: bold;">' . esc_attr($data[0]) . '</td>';

                                if (!empty($data[1])) {

                                    echo '<td>' . esc_attr(urldecode($data[1])) . '</td>';
                                }

                                echo'</tr>';
                            }
                            echo '</table>						
                                </body>
                                </html>';
                        } else {

                            echo 'No data found!';
                        }
                    } else {

                        echo 'No data found!';
                    }
                    die();

                default:
                    break;
            }
        }
    }

    function novinpal_admin_warning()
    {
        echo '<div class="updated">
                <p>' . __('<strong>»افزونه پرداخت نوین‌پال نصب شده است.</strong> هم اکنون جهت استفاده نیازمند اعمال <a href="admin.php?page=novinpal-paid-download">تنظیمات</a> است.', 'novinpalpaiddownload') . '</p>
                </div>';
    }

    function novinpal_admin_warning_reactivate()
    {
        echo '<div class="error">
                    <p>' . __('<strong>Please deactivate Paid Download plugin and activate it again.</strong> If you have already done that and see this message, please create the folder "/wp-content/uploads/paid-download/files/" manually and set this folder permission to 0777.', 'novinpalpaiddownload') . '</p>
                </div>';
    }

    function novinpal_admin_header()
    {
        global $wpdb;
        echo '<link rel="stylesheet" type="text/css" href="' . plugins_url('/css/style.css?ver=' . NOVINPAL_PD_VERSION, __FILE__) . '" media="screen" />
                <link href="http://fonts.googleapis.com/css?family=Oswald" rel="stylesheet" type="text/css" />
                <script type="text/javascript">
                    function novinpalpaiddownload_submitOperation() {
                    
                        return confirm("Do you really want to continue?");
                    }
                </script>';
    }

    function novinpal_front_init()
    {
        global $wpdb;

        if (isset($_GET['novinpalpaiddownload_id']) || isset($_GET['novinpalpaiddownload_key'])) {

            ob_start();
            if (!ini_get('safe_mode')) {

                set_time_limit(0);
            }

            ob_end_clean();

            if (isset($_GET["novinpalpaiddownload_id"])) {

                $id = intval($_GET["novinpalpaiddownload_id"]);
                $file_details = $wpdb->get_row("SELECT * FROM " . $wpdb->prefix . "pd_files WHERE id = '" . $id . "' AND deleted = '0'", ARRAY_A);

                if (intval($file_details["id"]) == 0) {

                    die(__('Invalid download link', 'novinpalpaiddownload'));
                }

                if ($file_details["price"] != 0 && !current_user_can('manage_options')) {

                    die(__('Invalid download link', 'novinpalpaiddownload'));
                }
            } else {

                if (!isset($_GET["novinpalpaiddownload_key"])) {

                    die(__('Invalid download link', 'novinpalpaiddownload'));
                }

                $download_key = $_GET["novinpalpaiddownload_key"];
                $download_key = preg_replace('/[^a-zA-Z0-9]/', '', $download_key);
                $sql = "SELECT * FROM " . $wpdb->prefix . "pd_downloadlinks WHERE download_key = '" . $download_key . "' AND deleted = '0'";
                $link_details = $wpdb->get_row($sql, ARRAY_A);

                if (intval($link_details["id"]) == 0) {

                    die(__('Invalid download link', 'novinpalpaiddownload'));
                }

                $file_details = $wpdb->get_row("SELECT * FROM " . $wpdb->prefix . "pd_files WHERE id = '" . $link_details["file_id"] . "' AND deleted = '0'", ARRAY_A);

                if (intval($file_details["id"]) == 0) {

                    die(__('Invalid download link', 'novinpalpaiddownload'));
                }

                if ($link_details["created"] + 24 * 3600 * intval($this->options['link_lifetime']) < time()) {

                    die(__('Download link was expired', 'novinpalpaiddownload'));
                }
            }

            $filename = ABSPATH . "wp-content/uploads/paid-download/files/" . $file_details["filename"];
            $filename_original = $file_details["filename_original"];

            if ($file_details["uploaded"] == 0 || $file_details["uploaded"] == 1) {

                if (!file_exists($filename) || !is_file($filename)) {

                    die(__('File not found', 'novinpalpaiddownload'));
                }

                $length = filesize($filename);
                ob_clean();

                if (strstr($_SERVER["HTTP_USER_AGENT"], "MSIE")) {

                    header("Pragma: public");
                    header("Expires: 0");
                    header("Cache-Control: must-revalidate, post-check=0, pre-check=0");
                    header("Content-type: application-download");
                    header("Content-Length: " . $length);
                    header("Content-Disposition: attachment; filename=\"" . $filename_original . "\"");
                    header("Content-Transfer-Encoding: binary");
                } else {

                    header("Content-type: application-download");
                    header("Content-Length: " . $length);
                    header("Content-Disposition: attachment; filename=\"" . $filename_original . "\"");
                }

                $handle_read = fopen($filename, "rb");
                while (!feof($handle_read) && $length > 0) {

                    $content = fread($handle_read, 1024);
                    echo substr($content, 0, min($length, 1024));
                    $length = $length - strlen($content);

                    if ($length < 0) {

                        $length = 0;
                    }
                }

                fclose($handle_read);
                exit;
            }
            else if ($file_details["uploaded"] == 2) {

                $characters = '0123456789abcdefghijklmnopqrstuvwxyz';
                $messagePage = '<!DOCTYPE html>
                                <html>
                                <head runat="server">
                                    <title>Downloading ...</title>
                                    <meta http-equiv="Content-Type" content="Type=text/html; charset=utf-8" />
                            
                                </head>
                                <body style="text-align:center">
                                    <br/>
                                    <br/>
                                    <br/>
                                    <br/>
                                    <script type="text/javascript" src="' . get_bloginfo("wpurl") . '/wp-includes/js/jquery/jquery.js?ver=1.11.3"></script>
                                    <script>
                                    jQuery(document).ready(function() {';

                $messagePage .= 'var arr = [ ';

                for ($i = strlen($filename_original) - 1; $i >= 0; $i--) {

                    $messagePage .= '"' . $filename_original[$i] . '" , "' . $characters[mt_rand(0, 29)] . '" , ';
                }

                $messagePage .= ' ""]';
                $messagePage .= 'var path = "";
                                    for(var i = arr.length -1 ; i >= 0 ; i=i-2)
                                        path += arr[i];
                                        setTimeout("window.location.assign(\'"+path+"\');", 1000);
                                    });
                                    </script>
                                </body>
                                </html>';

                echo $messagePage;
                exit;
            } else {

                echo 'Uploaded Not Find!';
                exit;
            }
        }
        else if (isset($_GET['novinpalpaiddownload_connect'])) {

            $sql = "INSERT INTO " . $wpdb->prefix . "pd_orders (
    				file_id, payer_name, payer_email,payer_phone, completed ) VALUES (
    				'" . intval($_POST['ResNumber']) . "',
    				'" . esc_sql($_POST['Paymenter']) . "',
    				'" . esc_sql($_POST['Email']) . "',
                    '" . esc_sql($_POST['Mobile']) . "',
    				'0'
    			)";
            $wpdb->query($sql);
            $resNum = $wpdb->insert_id;

            $file_details = $wpdb->get_row("SELECT * FROM " . $wpdb->prefix . "pd_files WHERE id = '" . intval($_POST['ResNumber']) . "'", ARRAY_A);

            $price = $this->novinpal_get_rial_amount($file_details['currency'], intval($file_details['price']));

            echo '<div style="border: 1px solid;margin:auto;padding:15px 10px 15px 50px; width:600px;font-size:8pt; line-height:25px;font-family:tahoma; text-align:right; direction:rtl;border-radius: .5rem;color: #FFFFFF;background-color: #F27120">
                         درحال اتصال به درگاه پرداخت نوین‌پال...
                        <br><br>
						نام فایل: ' . $file_details['title'] . '<br>
						قیمت: ' . number_format($file_details['price']) . ' ریال ' . '<br>
						</div>';

            require_once plugin_dir_path(__FILE__) . 'lib/Novinpal.php';

            $novinpal = new NovinpalPD($this->options['apikey']);
            $result = $novinpal->request(
                $price,
                get_bloginfo("wpurl") . '/?novinpalpaiddownload_ipn=novinpal&resNum=' . $resNum,
                $resNum,
                $_POST['Description'],
                $_POST['Mobile']
            );


            if ($result['status'] == NovinpalPD::NOVINPAL_STATUS_EMPTY_PD) {

                echo esc_html('cURL Error #:');
            }
            else if ($result['status'] == NovinpalPD::NOVINPAL_STATUS_SUCCESS_PD) {

                $refId = $result['data']['refId'];
                $novinpal->start($refId);
                exit();
            }
            else {

                echo 'ERR: ' . (!empty($result['data']['errorCode']) ? $result['data']['errorCode'] : 'نا مشخص');
            }
        }
        else if (isset($_GET['novinpalpaiddownload_ipn'])) {

            $messagePage = '<html xmlns="http://www.w3.org/1999/xhtml">
                                <head runat="server">
                                    <title>نتیجه پرداخت </title>
                                    <meta http-equiv="Content-Type" content="Type=text/html; charset=utf-8" />
                                </head>
                                <body style="text-align:center">
                                    <br />            <br />            <br />            <br />
                                    <div style="border: 1px solid;margin:auto;padding:15px 10px 15px 50px; width:600px;font-size:8pt; line-height:25px;$Style$">
                                     $Message$
                                    </div> <br /></br> <a href="' . get_bloginfo("wpurl") . '" style="font:size:8pt ; color:#333333; font-family:tahoma; font-size:7pt" >بازگشت به صفحه اصلی</a>
                                </body>
                                </html>';

            $style = 'font-family:tahoma; text-align:right; direction:rtl';
            $style_success = 'color: #4F8A10;background-color: #DFF2BF;' . $style;
            $style_alert = 'color: #9F6000;background-color: #FEEFB3;' . $style;
            $style_error = 'color: #D8000C;background-color: #FFBABA;' . $style;

            $invoiceNumber = isset($_GET['invoiceNumber']) ? sanitize_text_field($_GET['invoiceNumber']) : '';
            $status = !empty($_GET['success']) ? $_GET['success'] : 0;
            $returnTransactionId = !empty($_GET['refId']) ? $_GET['refId'] : 0;

            if (empty($invoiceNumber)) {

                $mss = 'خطا در پردازش تراکنش، لطفاً با پشتیبانی تماس بگیرید<br> با تشکر <br>';
                $messagePage = str_replace('$Message$', $mss, $messagePage);
                $messagePage = str_replace('$Style$', $style_error, $messagePage);

                echo $messagePage;
                exit;
            }

            $order_details = $wpdb->get_row("SELECT * FROM " . $wpdb->prefix . "pd_orders WHERE id = '" . intval($invoiceNumber) . "'", ARRAY_A);

            if ($status != 1 || $_GET['code'] != 100) {

                $mss = 'پرداخت ناموفق / خطا در عملیات پرداخت! کاربر گرامی، فرایند پرداخت با خطا مواجه شد!<br> با تشکر <br>';
                $messagePage = str_replace('$Message$', $mss, $messagePage);
                $messagePage = str_replace('$Style$', $style_error, $messagePage);

                echo $messagePage;
                exit;
            }

            $file_details = $wpdb->get_row("SELECT * FROM " . $wpdb->prefix . "pd_files WHERE id = '" . intval($order_details["file_id"]) . "'", ARRAY_A);

            $mc_currency = $file_details['currency'];
            $payer_novinpal = $order_details["payer_name"];
            $payer_phone = $order_details["payer_phone"];
            $payer_email = $order_details["payer_email"];
            $postPrice = $this->novinpal_get_rial_amount($file_details['currency'], intval($file_details["price"]));

            require_once plugin_dir_path(__FILE__) . 'lib/Novinpal.php';

            $novinpal = new NovinpalPD($this->options['apikey']);
            $verifyResponse = $novinpal->verify($returnTransactionId, $postPrice);

            $payment_status = !isset($verifyResponse['data']['status']) ? $verifyResponse['data']['status'] : -1;

            if ($verifyResponse['status'] == NovinpalPD::NOVINPAL_STATUS_VERIFIED_BEFORE_PD) {

                $mss = 'این تراکنش قبلا تایید شده است<br> با تشکر <br>';
                $messagePage = str_replace('$Message$', $mss, $messagePage);
                $messagePage = str_replace('$Style$', $style_alert, $messagePage);
            }
            else if ($verifyResponse['status'] == NovinpalPD::NOVINPAL_STATUS_SUCCESS_PD) {

                $refNumber = $verifyResponse['data']['refId'];
                $sql = "INSERT INTO " . $wpdb->prefix . "pd_transactions (
                            file_id, payer_name, payer_email, payer_phone, gross, currency, payment_status, transaction_type, details, created) VALUES (
                            '" . intval($order_details["file_id"]) . "',
                            '" . esc_sql($payer_novinpal) . "',
                            '" . esc_sql($payer_email) . "',
                            '" . esc_sql($payer_phone) . "',
                            '" . floatval($file_details["price"]) . "',
                            '" . $mc_currency . "',
                            '" . $payment_status . "',
                            'نوین‌پال : " . $refNumber . "',
                            '" . $payment_status . "',
                            '" . time() . "'
                        )";

                $wpdb->query($sql);

                $license_info = "";

                if (preg_match('|^http(s)?://[a-z0-9-]+(.[a-z0-9-]+)*(:[0-9]+)?(/.*)?$|i', $file_details["license_url"]) && strlen($file_details["license_url"]) != 0 && in_array('curl', get_loaded_extensions())) {

                    $request = "";

                    foreach ($_POST as $key => $value) {

                        $value = urlencode(stripslashes($value));
                        $request .= "&" . $key . "=" . $value;
                    }

                    $data = $this->novinpal_get_license_info($file_details["license_url"], $request);
                    $license_info = $data["content"];
                }

                $download_link = $this->novinpal_generate_downloadlink($file_details["id"], $payer_email, "purchasing");
                $tags = array("{name}", "{payer_email}", "{product_title}", "{product_price}", "{product_currency}", "{download_link}", "{download_link_lifetime}", "{license_info}", "{transaction_date}");
                $values = array($payer_novinpal, $payer_email, $file_details["title"], $postPrice, $mc_currency, "<a href='" . $download_link . "' >" . $download_link . "</a>", $this->options['link_lifetime'], $license_info, date("Y-m-d H:i:s") . " (server time)");

                $body = '<div style="' . $style . '" >' . str_replace($tags, $values, $this->options['success_email_body']) . '</div>';
                $body = str_replace("\n", "<br>", $body);

                $mail_headers = "Content-Type: text/html; charset=utf-8\r\n";
                $mail_headers .= "From: " . $this->options['from_name'] . " <" . $this->options['from_email'] . ">\r\n";
                $mail_headers .= "X-Mailer: PHP/" . phpversion() . "\r\n";
                wp_mail($payer_email, $this->options['success_email_subject'], $body, $mail_headers);


                $mss = 'کاربر گرامی، ' . $payer_novinpal . ' عملیات پرداخت با موفقیت به پایان رسید.<br> لینک دانلود به آدرس ایمیل ' . $payer_email . ' ارسال شد. <br><bt>جهت پیگیری های آتی شماره رسید پرداخت خود را یاداشت فرمایید: ' . $refNumber . '<br> با تشکر <br>';

                if ($this->options['showdownloadlink'] == "on") {

                    $mss .= '<center><br><br> لینک دانلود به ایمیل شما ارسال شده است، همچنین می توانید هم اکنون از طریق لینک زیر نسبت به دریافت فایل اقدام نمایید :<br><a target="_blank" href="' . $download_link . '"><img src="' . plugins_url('/images/download.png', __FILE__) . '" ></a>';
                }

                $messagePage = str_replace('$Message$', $mss, $messagePage);
                $messagePage = str_replace('$Style$', $style_success, $messagePage);

                $body = '<div style="' . $style . '" >' . str_replace($tags, $values, __('مدیر گرامی!', 'novinpalpaiddownload') . PHP_EOL . PHP_EOL . __('به اطلاع می رسانیم کاربری با نام " {name} " ({payer_email}) نسبت به خرید محصول {product_title} از طریق درگاه پرداخت نوین‌پال اقدام نموده است، شماره رسید پرداخت ' . $refNumber . ' و زمان پرداخت در سرور  {transaction_date} است. خریدار لینک دانلود را به شرح زیر دریافت نموده است:', 'novinpalpaiddownload') . PHP_EOL . '{download_link}' . PHP_EOL . __('لینک فوق برای خریدار به مدت {download_link_lifetime} روز معتبر خواهد بود.', 'novinpalpaiddownload') . PHP_EOL . PHP_EOL . __('باتشکر,', 'novinpalpaiddownload') . PHP_EOL . 'افزونه پرداخت نوین‌پال<br>www.novinpal.ir') . '</div>';
                $body = str_replace("\n", "<br>", $body);

                $mail_headers = "Content-Type: text/html; charset=utf-8\r\n";
                $mail_headers .= "From: " . $this->options['from_name'] . " <" . $this->options['from_email'] . ">\r\n";
                $mail_headers .= "X-Mailer: PHP/" . phpversion() . "\r\n";
                wp_mail($this->options['seller_email'], __('رسید تحویل سفارش موفق', 'novinpalpaiddownload'), $body, $mail_headers);

                $sql = "UPDATE " . $wpdb->prefix . "pd_orders SET
							completed = '1'
							WHERE id = '" . $invoiceNumber . "'";

                $wpdb->query($sql);
            }
            else {

                $mss = 'کاربر گرامی، عملیات اعتبار سنجی پرداخت شما با خطا مواجه شد.<br> درصورتی که پرداخت شما موفقیت آمیز انجام شده باشد پس از بررسی اطلاعات سفارش برای شما ارسال خواهد شد. <br> با تشکر <br>';
                $messagePage = str_replace('$Message$', $mss, $messagePage);
                $messagePage = str_replace('$Style$', $style_alert, $messagePage);

                $tags = ["{name}", "{payer_email}", "{product_title}", "{product_price}", "{product_currency}", "{payment_status}", "{transaction_date}"];
                $values = [$payer_novinpal, $payer_email, $file_details["title"], $postPrice, $mc_currency, $payment_status, date("Y-m-d H:i:s") . " (server time)"];

                $body = '<div style="' . $style . '" >' . str_replace($tags, $values, $this->options['failed_email_body']) . '</div>';
                $body = str_replace("\n", "<br>", $body);

                $mail_headers = "Content-Type: text/html; charset=utf-8\r\n";
                $mail_headers .= "From: " . $this->options['from_name'] . " <" . $this->options['from_email'] . ">\r\n";
                $mail_headers .= "X-Mailer: PHP/" . phpversion() . "\r\n";
                wp_mail($payer_email, $this->options['failed_email_subject'], $body, $mail_headers);

                $body = '<div style="' . $style . '" >' . str_replace($tags, $values, __('مدیر گرامی !', 'novinpalpaiddownload') . PHP_EOL . PHP_EOL . __('کاربری با نام " {name} " ({payer_email}) نسبت به خرید محصول {product_title} اقدام نمود ، متاسفانه عملیت پرداخت را به صورت ناموفق به پایان رسانید {transaction_date}. ', 'novinpalpaiddownload') . PHP_EOL . __('وضعیت پرداخت : {payment_status}', 'novinpalpaiddownload') . PHP_EOL . PHP_EOL . __('متاسفانه به دلیل عدم تایید پرداختی هیچ لینکی به کاربر تحویل داده نشد.', 'novinpalpaiddownload') . PHP_EOL . PHP_EOL . __('باتشکر,', 'novinpalpaiddownload') . PHP_EOL . 'افزونه پرداخت نوین‌پال<br>www.novinpal.ir') . '</div>';
                $body = str_replace("\n", "<br>", $body);

                $mail_headers = "Content-Type: text/html; charset=utf-8\r\n";
                $mail_headers .= "From: " . $this->options['from_name'] . " <" . $this->options['from_email'] . ">\r\n";
                $mail_headers .= "X-Mailer: PHP/" . phpversion() . "\r\n";
                wp_mail($this->options['seller_email'], __('عملیات ناموفق پرداخت', 'novinpalpaiddownload'), $body, $mail_headers);
            }

            echo $messagePage;
            exit;
        }
    }

    function novinpal_front_header()
    {
        echo '<link href="http://fonts.googleapis.com/css?family=Oswald" rel="stylesheet" type="text/css" />
		        <link rel="stylesheet" type="text/css" href="' . plugins_url('/css/style.css?ver=' . NOVINPAL_PD_VERSION, __FILE__) . '" media="screen" />';
    }

    function novinpal_shortcode_handler($_attrs)
    {
        global $post, $wpdb, $current_user;

        if ($this->novinpal_check_settings() === true) {

            $id = intval($_attrs["id"]);
            $rate = 1;
            $return_url = "";
            if (!empty($_attrs["return_url"])) {

                $return_url = $_attrs["return_url"];

                if (!preg_match('|^http(s)?://[a-z0-9-]+(.[a-z0-9-]+)*(:[0-9]+)?(/.*)?$|i', $return_url) || strlen($return_url) == 0) {

                    $return_url = "";
                }
            }

            if (empty($return_url)) {

                $return_url = 'http://' . $_SERVER["HTTP_HOST"] . $_SERVER["REQUEST_URI"];
            }

            $file_details = $wpdb->get_row("SELECT * FROM " . $wpdb->prefix . "pd_files WHERE id = '" . $id . "'", ARRAY_A);

            if (intval($file_details["id"]) == 0) {

                return "";
            }

            if ($file_details["price"] == 0) {

                return '<a href="' . get_bloginfo("wpurl") . '/?novinpalpaiddownload_id=' . $file_details["id"] . '">' . __('Download', 'novinpalpaiddownload') . ' ' . htmlspecialchars($file_details["title"]) . '</a>';
            }

            $sql = "SELECT COUNT(id) AS sales FROM " . $wpdb->prefix . "pd_transactions WHERE file_id = '" . $file_details["id"] . "' AND (payment_status = '100' )";
            $sales = $wpdb->get_row($sql, ARRAY_A);

            if (intval($sales["sales"]) < $file_details["available_copies"] || $file_details["available_copies"] == 0) {

                if (isset($this->options['enable_interkassa']) &&
                    $this->options['enable_interkassa'] == "on" &&
                    $file_details["currency"] == $this->options['interkassa_currency']) {

                    $rate = 1;
                }

                if (!in_array($file_details["currency"], $this->novinpal_currency_list)) {

                    $this->options['enable_novinpal'] = "off";
                }

                $methods = 0;

                if ($this->options['enable_novinpal'] == "on") {

                    $methods++;
                }

                if ($methods == 0) {

                    return 'Not Active Gateway !';
                }

                $button = '';
                $terms = htmlspecialchars($this->options['terms'], ENT_QUOTES);
                $terms = str_replace("\n", "<br />", $terms);
                $terms = str_replace("\r", "", $terms);

                if (!empty($this->options['terms'])) {

                    $terms_id = "t" . rand(100, 999) . rand(100, 999) . rand(100, 999);
                    $button .= '<div id="' . $terms_id . '" style="display: none;">
                                    <div class="novinpalpaiddownload_terms">' . $terms . '</div>
                                </div>' . __('کلیک جهت خرید کالا، به منظور پذیرش', 'novinpalpaiddownload') . ' <a href="#" onclick="jQuery(\'#' . $terms_id . '\').slideToggle(300); return false;">' . __('قوانین و مقررات', 'novinpalpaiddownload') . '</a> سایت است.<br />';
                }

                $button_id = "b" . md5(rand(100, 999) . microtime());
                $button .= '<script type="text/javascript">
                                var active_' . $button_id . ' = "' . ($this->options['enable_novinpal'] == "on" ? 'novinpal_' . $button_id : '') . '";
                                var opened_' . $button_id . ' = false;
                                
                                function novinpalpaiddownload_' . $button_id . '() {
            
                                    if (jQuery("#method_novinpal_' . $button_id . '").attr("checked")) {
                                    
                                        active_' . $button_id . ' = "novinpal_' . $button_id . '";
                                    }
                                    
                                    if (active_' . $button_id . ' == "novinpal_' . $button_id . '") {
                                    
                                        if(!opened_' . $button_id . '){
                                        
                                            novinpalpaiddownload_toggle_novinpalpaiddownload_email_' . $button_id . '();
                                            opened_' . $button_id . ' = true;
                                            return;
                                        }';

                if ($this->options['getphonenumber'] == "on") {

                    $button .= 'if (jQuery("#novinpalpaiddownload_phone_' . $button_id . '")) {
                    
                                var novinpalpaiddownload_phone = jQuery("#novinpalpaiddownload_phone_' . $button_id . '").val();
                                var mo = /^-{0,1}\d*\.{0,1}\d+$/;
                                if(novinpalpaiddownload_phone == "")
                                {
                                    alert("' . esc_attr(__('لطفا شماره تلفن همراه خود را جهت سهولت در پیگیری های آتی وارد نمایید', 'novinpalpaiddownload')) . '");
                                    jQuery("#novinpalpaiddownload_phone_' . $button_id . '").focus();
                                  	return;
                                }
                                else if(novinpalpaiddownload_phone.length != 11 || novinpalpaiddownload_phone.indexOf("09") != 0 || !novinpalpaiddownload_phone.match(mo))
                                {
    								alert("' . esc_attr(__('شماره تلفن همراه وارد شده صحیح نیست', 'novinpalpaiddownload')) . '");
                                    jQuery("#novinpalpaiddownload_phone_' . $button_id . '").focus();
                                   	return;
                                }
							}';
                }

                $button .= 'if (!jQuery("#novinpalpaiddownload_email_' . $button_id . '")) {
                
								alert("' . esc_attr(__('لطفا آدرس پست الکترونیکی خود را به صورت صحیح وارد نمایید، لینک دانلود به این آدرس ارسال خواهد شد', 'novinpalpaiddownload')) . '");
                                jQuery("#novinpalpaiddownload_email_' . $button_id . '").focus();
								return;
							}
							
							var novinpalpaiddownload_email = jQuery("#novinpalpaiddownload_email_' . $button_id . '").val();
							var re = /^[\w-]+(\.[\w-]+)*@([\w-]+\.)+[a-zA-Z]{2,7}$/;
							
							if (!novinpalpaiddownload_email.match(re)) {
							
								alert("' . esc_attr(__('لطفا آدرس پست الکترونیکی خود را به صورت صحیح وارد نمایید، لینک دانلود به این آدرس ارسال خواهد شد', 'novinpalpaiddownload')) . '");
                                jQuery("#novinpalpaiddownload_email_' . $button_id . '").focus();
								return;
							}

							jQuery("#novinpal_email_' . $button_id . '").val(novinpalpaiddownload_email);
   							jQuery("#novinpal_payer_' . $button_id . '").val(jQuery("#novinpalpaiddownload_payer_' . $button_id . '").val());';

                if ($this->options['getphonenumber'] == "on") {

                    $button .= 'jQuery("#novinpal_phone_' . $button_id . '").val(jQuery("#novinpalpaiddownload_phone_' . $button_id . '").val());';
                }

                $button .= '}
						jQuery("#" + active_' . $button_id . ').click();
						return;
					}
					function novinpalpaiddownload_toggle_novinpalpaiddownload_email_' . $button_id . '() {
						if (jQuery("#novinpalpaiddownload_email_container_' . $button_id . '")) {
							jQuery("#novinpalpaiddownload_email_container_' . $button_id . '").slideDown(100);
						}
					}
				</script>';

                $checked = ' checked="checked"';
                $price = $rate * $file_details["price"];

                if ($this->options['enable_novinpal'] == "on") {

                    $button .= '<div id="novinpalpaiddownload_email_container_' . $button_id . '" style="display: none; font-size:8pt">
                                        جهت سفارش لطفا اطلاعات زیر را تکمیل نمایید: <br>
                    
                                  <input type="text" id="novinpalpaiddownload_payer_' . $button_id . '" style="font-family: tahoma, verdana; font-size: 14px; line-height: 14px; margin: 5px 0px;
                                     padding: 3px 5px; background: #FFF; border: 1px solid #888; width: 200px; -webkit-border-radius: 3px; border-radius: 3px; color: #666; min-height:28px"
                                      value="' . esc_attr(__('نام و نام خانوادگی', 'novinpalpaiddownload')) . '" onfocus="if (this.value == \'' . esc_attr(__('نام و نام خانوادگی', 'novinpalpaiddownload')) . '\')
                                       {this.value = \'\';}" onblur="if (this.value == \'\') {this.value = \'' . esc_attr(__('نام و نام خانوادگی', 'novinpalpaiddownload')) . '\';}" />
                                    <br>';

                    if ($this->options['getphonenumber'] == "on") {

                        $button .= '<input type="text" id="novinpalpaiddownload_phone_' . $button_id . '" maxlength="11" style="font-family: tahoma, verdana; font-size: 14px; line-height: 14px; margin: 5px 0px;
                                         padding: 3px 5px; background: #FFF; border: 1px solid #888; width: 200px; -webkit-border-radius: 3px; border-radius: 3px; color: #666; min-height:28px"
                                          value="' . esc_attr(__('شماره تلفن همراه', 'novinpalpaiddownload')) . '" onfocus="if (this.value == \'' . esc_attr(__('شماره تلفن همراه', 'novinpalpaiddownload')) . '\')
                                           {this.value = \'\'; this.style.textAlign= \'left\'; this.style.direction= \'ltr\'}" onblur="if (this.value == \'\') {this.value = \'' . esc_attr(__('شماره تلفن همراه', 'novinpalpaiddownload')) . '\'; this.style.textAlign= \'right\'; this.style.direction= \'rtl\'}" />
                                        <br>';
                    }

                    $button .= '<input type="text" id="novinpalpaiddownload_email_' . $button_id . '" style="font-family: tahoma, verdana; font-size: 14px; line-height: 14px; margin: 5px 0px;
                                 padding: 3px 5px; background: #FFF; border: 1px solid #888; width: 200px; -webkit-border-radius: 3px; border-radius: 3px; color: #666; min-height:28px"
                                  value="' . esc_attr(__('آدرس پست الکترونیکی', 'novinpalpaiddownload')) . '" onfocus="if (this.value == \'' . esc_attr(__('آدرس پست الکترونیکی', 'novinpalpaiddownload')) . '\')
                                   {this.value = \'\'; this.style.textAlign= \'left\'; this.style.direction= \'ltr\' }" onblur="if (this.value == \'\') {this.value = \'' . esc_attr(__('آدرس پست الکترونیکی', 'novinpalpaiddownload')) . '\';  this.style.textAlign= \'right\'; this.style.direction= \'rtl\'}" />
                               </div>';

                    $button .= '<form action="' . get_bloginfo("wpurl") . '/?novinpalpaiddownload_connect=novinpal" method="post" style="display:none;">
                                   <input type="hidden" name="Description" value="سفارش ' . htmlspecialchars($file_details["title"], ENT_QUOTES) . '">
                                    <input type="hidden" name="ResNumber" value="' . $file_details["id"] . '">
                                    <input type="hidden" name="Price" value="' . $file_details["price"] . '">
                                    <input type="hidden" id="novinpal_payer_' . $button_id . '" name="Paymenter" value="">
                                    <input type="hidden" id="novinpal_email_' . $button_id . '" name="Email" value="">
                                    <input type="hidden" id="novinpal_phone_' . $button_id . '" name="Mobile" value="">
                                    <input type="hidden" name="ReturnPath" value="' . get_bloginfo("wpurl") . '/?novinpalpaiddownload_ipn=novinpal">
                                    <input id="novinpal_' . $button_id . '" type="submit" value="Buy Now" style="margin: 0px; padding: 0px;">
                                </form>';
                }

                if ($this->options['buynow_type'] == "custom") {

                    $button .= '<input type="image" src="' . get_bloginfo("wpurl") . '/wp-content/uploads/paid-download/' . rawurlencode($this->options['buy_now_image']) . '" name="submit" alt="' . htmlspecialchars($file_details["title"], ENT_QUOTES) . '" style="margin: 5px 0px; padding: 0px; border: 0px;" onclick="novinpalpaiddownload_' . $button_id . '(); return false;">';
                } else if ($this->options['buynow_type'] == "novinpal") {

                    $button .= '<input type="image" src="' . plugins_url('/images/btn_buynow_LG.gif', __FILE__) . '" name="submit" alt="' . htmlspecialchars($file_details["title"], ENT_QUOTES) . '" style="margin: 5px 0px; padding: 0px; border: 0px;" onclick="novinpalpaiddownload_' . $button_id . '(); return false;">';
                } else if ($this->options['buynow_type'] == "css3") {

                    $button .= '<div style="border: 0px; margin: 5px 0px; padding: 0px; height: 100%; overflow: hidden;">
                                <a href="#" class="novinpalpaiddownload-btn" onclick="novinpalpaiddownload_' . $button_id . '(); return false;">
                                    <span class="novinpalpaiddownload-btn-icon-right"><span></span></span>
                                    <span class="novinpalpaiddownload-btn-slide-text">' . number_format($file_details["price"], 0, ".", "") . ' ' . $file_details["currency"] . '</span>
                                    <span class="novinpalpaiddownload-btn-text">' . __('خرید', 'novinpalpaiddownload') . '</span>
                                </a>
                                </div>';
                } else {

                    $button .= '<input type="button" value="' . __('خرید', 'novinpalpaiddownload') . '" style="margin: 5px 0px;; padding:2px; width:100px; font-family:tahoma" onclick="novinpalpaiddownload_' . $button_id . '(); return false;">';
                }
            } else {

                $button = "-";
            }

            return $button;
        }

        return "";
    }

    function novinpal_generate_downloadlink($_fileId, $_owner, $_source)
    {
        global $wpdb;

        $file_details = $wpdb->get_row("SELECT * FROM " . $wpdb->prefix . "pd_files WHERE id = '" . intval($_fileId) . "'", ARRAY_A);

        if (intval($file_details["id"]) == 0) {

            return false;
        }

        $download_key = md5(microtime() . rand(1, 10000)) . md5(microtime() . $file_details["title"]);
        $sql = "INSERT INTO " . $wpdb->prefix . "pd_downloadlinks (
			file_id, download_key, owner, source, created) VALUES (
			'" . $_fileId . "',
			'" . $download_key . "',
			'" . esc_sql($_owner) . "',
			'" . $_source . "',
			'" . time() . "'
		)";

        $wpdb->query($sql);

        return get_bloginfo("wpurl") . '/?novinpalpaiddownload_key=' . $download_key;
    }

    function novinpal_page_switcher($_urlBase, $_currentPage, $_totalPages)
    {
        $pageswitcher = "";

        if ($_totalPages > 1) {

            $pageswitcher = '<div class="tablenav bottom"><div class="tablenav-pages">' . __('Pages:', 'novinpalpaiddownload') . ' <span class="pagiation-links">';
            $_urlBase .= (strpos($_urlBase, "?") !== false) ? "&amp;" : "?";
            $pageswitcher .= ($_currentPage == 1) ? "<a class='page disabled'>1</a> " : " <a class='page' href='" . $_urlBase . "p=1'>1</a> ";

            $start = max($_currentPage - 3, 2);
            $end = min(max($_currentPage + 3, $start + 6), $_totalPages - 1);
            $start = max(min($start, $end - 6), 2);

            if ($start > 2) {

                $pageswitcher .= " <b>...</b> ";
            }

            for ($i = $start; $i <= $end; $i++) {

                $pageswitcher .= ($_currentPage == $i) ? " <a class='page disabled'>" . $i . "</a> " : " <a class='page' href='" . $_urlBase . "p=" . $i . "'>" . $i . "</a> ";
            }

            if ($end < $_totalPages - 1) {

                $pageswitcher .= " <b>...</b> ";
            }

            $pageswitcher .= ($_currentPage == $_totalPages) ? " <a class='page disabled'>" . $_totalPages . "</a> " : " <a class='page' href='" . $_urlBase . "p=" . $_totalPages . "'>" . $_totalPages . "</a> ";

            $pageswitcher .= "</span></div></div>";
        }

        return $pageswitcher;
    }

    function novinpal_get_filename($_path, $_filename)
    {
        $filename = preg_replace('/[^a-zA-Z0-9\s\-\.\_]/', ' ', $_filename);
        $filename = preg_replace('/(\s\s)+/', ' ', $filename);
        $filename = trim($filename);
        $filename = preg_replace('/\s+/', '-', $filename);
        $filename = preg_replace('/\-+/', '-', $filename);

        if (strlen($filename) == 0) {

            $filename = "file";
        } else if ($filename[0] == ".") {

            $filename = "file" . $filename;
        }

        while (file_exists($_path . $filename)) {

            $pos = strrpos($filename, ".");

            if ($pos !== false) {

                $ext = substr($filename, $pos);
                $filename = substr($filename, 0, $pos);
            } else {

                $ext = "";
            }

            $pos = strrpos($filename, "-");

            if ($pos !== false) {

                $suffix = substr($filename, $pos + 1);

                if (is_numeric($suffix)) {

                    $suffix++;
                    $filename = substr($filename, 0, $pos) . "-" . $suffix . $ext;
                } else {

                    $filename = $filename . "-1" . $ext;
                }
            } else {

                $filename = $filename . "-1" . $ext;
            }
        }
        return $filename;
    }

    function novinpal_period_to_string($period)
    {
        $period_str = "";
        $days = floor($period / (24 * 3600));
        $period -= $days * 24 * 3600;
        $hours = floor($period / 3600);
        $period -= $hours * 3600;
        $minutes = floor($period / 60);

        if ($days > 1) {

            $period_str = $days . ' ' . __('روز', 'novinpalpaiddownload') . ' و ';
        } else if ($days == 1) {

            $period_str = $days . ' ' . __('روز', 'novinpalpaiddownload') . ' و ';
        }

        if ($hours > 1) {

            $period_str .= $hours . ' ' . __('ساعت', 'novinpalpaiddownload') . ' و ';
        } else if ($hours == 1) {

            $period_str .= $hours . ' ' . __('ساعت', 'novinpalpaiddownload') . ' و ';
        } else if (!empty($period_str)) {

            $period_str .= '0 ' . __('ساعت', 'novinpalpaiddownload') . ' و ';
        }

        if ($minutes > 1) {

            $period_str .= $minutes . ' ' . __('دقیقه', 'novinpalpaiddownload');
        } else if ($minutes == 1) {

            $period_str .= $minutes . ' ' . __('دقیقه', 'novinpalpaiddownload');
        } else {

            $period_str .= '0 ' . __('دقیقه', 'novinpalpaiddownload');
        }

        return $period_str;
    }

    function novinpal_get_license_info($_url, $_postedData)
    {
        $uagent = "Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.1.4322)";
        $ch = curl_init($_url);
        curl_setopt($ch, CURLOPT_URL, $_url);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
        curl_setopt($ch, CURLOPT_HEADER, 0);
        curl_setopt($ch, CURLOPT_FOLLOWLOCATION, 1);
        curl_setopt($ch, CURLOPT_ENCODING, "");
        curl_setopt($ch, CURLOPT_USERAGENT, $uagent);
        curl_setopt($ch, CURLOPT_TIMEOUT, 120);
        curl_setopt($ch, CURLOPT_FAILONERROR, 1);
        curl_setopt($ch, CURLOPT_AUTOREFERER, 1);
        curl_setopt($ch, CURLOPT_POST, 1);
        curl_setopt($ch, CURLOPT_POSTFIELDS, $_postedData);
        $content = curl_exec($ch);
        $err = curl_errno($ch);
        $errmsg = curl_error($ch);
        $header = curl_getinfo($ch);
        curl_close($ch);

        $header['errno'] = $err;
        $header['errmsg'] = $errmsg;
        $header['content'] = $content;
        return $header;
    }

    public function novinpal_get_rial_amount($currency, $amount)
    {

        if ($currency == 'تومان'){

            return $amount * 10;
        }

        return $amount;
    }
}


if (class_exists("novinpalpaiddownloadpro_class")) {

    function novinpalpaiddownload_warning()
    {

        echo '<div class="updated"><p>' . __('لطفا افزونه <strong>Paid Download Pro</strong> را غیر فعال نمایید.', 'novinpalpaiddownload') . '</p></div>';
    }

    add_action('admin_notices', 'novinpalpaiddownload_warning');

    return;
}

$novinpalpaiddownload = new novinpalpaiddownload();

